'=====================================================================
' Presample Analysis: 1970 - 1982
'
' "A Bayesian Look at New Open Economy Macroeconomics"
' by Thomas Lubik and Frank Schorfheide
'
' Coded for EViews 4.1
' Last Updated: 05/02/2005 
'=====================================================================

' run us_euro.prg first!!

' set working directory path
%path = @runpath
' comment off line 13 if @runpath is not supported on your version of EViews
' elaborate in writing on your data directory, for example,
%path = "c:\projects\active\nber\data\us_euro\"
'cd "{%path}"

%smpl_f = "1970:1"
%smpl_l = "1982:4"

' create workfile
workfile presample q 1947:1 2005:4

' US data series
' open FRED database and fetch series
db {%path}\us_fred\bnoe_fred2_us
fetch us_cpiinfl us_gdpgr_w fred2_us_fedfunds fred2_us_exp fred2_us_imp fred2_us_gdpr

' EURO data series
' open AWM database and fetch series
db {%path}\euro_awm\bnoe_euroland
fetch eu_cpiinfl eu_gdpgr awm_stn awm_xtr awm_mtr awm_yer eu_fxdep


' generate series for presample analysis
smpl {%smpl_f} {%smpl_l}

genr us_gdprgr = us_gdpgr_w
genr us_infl   = us_cpiinfl
genr us_impsh  = fred2_us_imp/(fred2_us_gdpr-fred2_us_exp+fred2_us_imp)
genr us_realr  = fred2_us_fedfunds(-1) - us_infl

genr euro_gdprgr = eu_gdpgr
genr euro_infl   = eu_cpiinfl
genr euro_impsh  = awm_mtr/(awm_yer-awm_xtr+awm_mtr)
genr euro_realr  = awm_stn(-1) - euro_infl

genr e_del = eu_fxdep

' presample analysis
equation usrealr.ls us_realr c AR(1)
equation eurorealr.ls euro_realr c AR(1)

equation usimpsh.ls us_impsh c AR(1)
equation euroimpsh.ls euro_impsh c AR(1)

equation euro_gr.ls euro_gdprgr c AR(1)
equation us_gr.ls us_gdprgr c AR(1)

equation euro_pi.ls euro_infl c AR(1)
equation us_pi.ls us_infl c AR(1)

equation euro_stn.ls awm_stn c awm_stn(-1) euro_gdprgr(-1) euro_infl(-1)
equation us_fedfund.ls fred2_us_fedfunds c fred2_us_fedfunds(-1) us_gdprgr(-1) us_infl(-1)

equation edel.ls e_del c AR(1)

' output for DYNARE
write(t=txt,na=.,d=c,nodates,nonames) presample.txt us_gdprgr euro_gdprgr

' save workfile
save

