'=====================================================================
' Data preparation for
'
' "A Bayesian Look at New Open Economy Macroeconomics"
' by Thomas	Lubik and Frank	Schorfheide
'
' Coded	for	EViews 4.1
' by Sungbae An
' Last Updated:	04/28/2005
'=====================================================================

' set working directory	path
%path =	@runpath
' comment off line 13 if @runpath is not supported on your version of EViews
' elaborate in writing on your data directory, for example,
' %path = "d:\work\bnoe\data\"
cd "{%path}"

' create database
db {%path}bnoe_euroland

' set country code
%cn="AT BE DE ES FI FR GR IE IT LU NL PT"
' AUSTRIA(AT) BELGIUM(BE) FRANCE(FR) GERMANY(DE)
' ITALY(IT) LUXEMBOURG(LU) NETHERLANDS(NE) FINLAND(FI)
' GREECE(GR) IRELAND(IE) PORTUGAL(PT) SPAIN(ES)
' EURO_AREA(EU)


'--------------------------------------------------------------------
' Annual data
'--------------------------------------------------------------------
' create a workfile
workfile bnoe_euroland a 1960 2006

'------------------------------------------------
' Population
'------------------------------------------------
' ifs_pop_euroland.xls
' total population
' millions
read(b10) ifs_pop_euroland.xls IFS_AT_POP IFS_BE_POP IFS_FR_POP IFS_DE_POP IFS_IT_POP IFS_LU_POP IFS_NL_POP IFS_FI_POP IFS_GR_POP IFS_IE_POP IFS_PT_POP IFS_ES_POP

' add up to EU_POP
' change the unit to thousands
' set low-to-high frequency	conversion method
genr EU_POP = 0

for	!i=0 to	11
	%cnn = @mid(%cn,1+3*!i,2)
	genr IFS_{%cnn}_POP = 1000*IFS_{%cnn}_POP
	genr EU_POP = EU_POP + IFS_{%cnn}_POP
	IFS_{%cnn}_POP.setconvert q		' quadratic	average
next
EU_POP.setconvert q

' store into the database
store IFS_AT_POP IFS_BE_POP IFS_FR_POP IFS_DE_POP IFS_IT_POP IFS_LU_POP IFS_NL_POP IFS_FI_POP IFS_GR_POP IFS_IE_POP IFS_PT_POP IFS_ES_POP EU_POP

' ameco_pop.txt
' age 15-64
' in thousands
read(skiprow=2,skipcol=1,d=c,na=#N/A) ameco_pop.csv AMECO_POP AMECO_POP_WG

' extend AMECO_POP to pre-1991 using the growth rate of AMECO_POP_WG
genr POP_GR = AMECO_POP_WG/AMECO_POP_WG(-1)
genr EU_WPOP = AMECO_POP

for	!i=1990 to 1960 step -1
	smpl !i !i
	genr EU_WPOP = EU_WPOP(+1)/POP_GR(+1)
next
smpl @all

' set low-to-high frequency	conversion method
EU_WPOP.setconvert q
AMECO_POP.setconvert q
AMECO_POP_WG.setconvert q

' store into the database
store EU_WPOP AMECO_POP AMECO_POP_WG

' close workfile
close bnoe_euroland


'--------------------------------------------------------------------
' Quarterly data
'--------------------------------------------------------------------
' create a workfile
workfile bnoe_euroland q 1970 2003

'------------------------------------------------
' Area-Wide Model dataset
'------------------------------------------------
' Awm12up5.xls
read(b6,s=AWM12UP5) Awm12up5.xls AWM_CAN AWM_COMPR AWM_D774781 AWM_D81Q1 AWM_D82Q1 AWM_D841 AWM_D84Q2 AWM_D872 AWM_D891924 AWM_D894 AWM_D911P AWM_D92Q4 AWM_D93Q1 AWM_D971P AWM_D98Q1 AWM_D993P AWM_DS1 AWM_DS2 AWM_DS3 AWM_DS4 AWM_EEN AWM_EER AWM_FDD AWM_GCD AWM_GCN AWM_GCN_YEN AWM_GCR AWM_GDN AWM_GDN_DIS AWM_GDN_DIS_YEN AWM_GDN_YEN AWM_GEN AWM_GEN_YEN AWM_GIN AWM_GIN_OTHER AWM_GIN_OTHER_YEN AWM_GIN_YEN AWM_GIX AWM_GLN AWM_GLN_DIS AWM_GLN_DIS_YEN AWM_GLN_YEN AWM_GON AWM_GPN AWM_GPN_YEN AWM_GRN AWM_GRN_YEN AWM_GSN AWM_GSN_YEN AWM_GYN AWM_GYN_AWM_YEN AWM_HEG AWM_HEX AWM_HICP AWM_INFQ AWM_INFT AWM_INN AWM_INN_YEN AWM_ITD AWM_ITN AWM_ITR AWM_KSR AWM_LEN AWM_LFN AWM_LNN AWM_LNT AWM_LPROD AWM_LSL AWM_LSR AWM_LTN AWM_MTD AWM_MTN AWM_MTR AWM_NFA AWM_NFN AWM_NFN_YEN AWM_OGN AWM_OGN_YEN AWM_PCD AWM_PCN AWM_PCR AWM_PYN AWM_PYN_DIS AWM_PYN_DIS_YEN AWM_PYR AWM_S1 AWM_S3 AWM_SCD AWM_SCN AWM_SCR AWM_SSN AWM_SSN_YEN AWM_STN AWM_STRQ AWM_T931P AWM_TBN AWM_TBR AWM_TDN AWM_TDN_YEN AWM_TFT AWM_TIME AWM_TIN AWM_TIN_YEN AWM_TKN AWM_TKN_YEN AWM_TRN AWM_TRN_FIRMS AWM_TRN_FIRMS_YEN AWM_TRN_OTHER AWM_TRN_OTHER_YEN AWM_TRN_YEN AWM_ULC AWM_ULT AWM_UNN AWM_URT AWM_URX AWM_WIN AWM_WLN AWM_WLR AWM_WRN AWM_XTD AWM_XTN AWM_XTR AWM_YED AWM_YEN AWM_YEN_DIS AWM_YER AWM_YER_DIS AWM_YET AWM_YFD AWM_YFN AWM_YGA AWM_YIN AWM_YIN_DIS AWM_YWD AWM_YWDX AWM_YWR AWM_YWRX

' store into the database
store AWM_CAN AWM_COMPR AWM_D774781 AWM_D81Q1 AWM_D82Q1 AWM_D841 AWM_D84Q2 AWM_D872 AWM_D891924 AWM_D894 AWM_D911P AWM_D92Q4 AWM_D93Q1 AWM_D971P AWM_D98Q1 AWM_D993P AWM_DS1 AWM_DS2 AWM_DS3 AWM_DS4 AWM_EEN AWM_EER AWM_FDD AWM_GCD AWM_GCN AWM_GCN_YEN AWM_GCR AWM_GDN AWM_GDN_DIS AWM_GDN_DIS_YEN AWM_GDN_YEN AWM_GEN AWM_GEN_YEN AWM_GIN AWM_GIN_OTHER AWM_GIN_OTHER_YEN AWM_GIN_YEN AWM_GIX AWM_GLN AWM_GLN_DIS AWM_GLN_DIS_YEN AWM_GLN_YEN AWM_GON AWM_GPN AWM_GPN_YEN AWM_GRN AWM_GRN_YEN AWM_GSN AWM_GSN_YEN AWM_GYN AWM_GYN_AWM_YEN AWM_HEG AWM_HEX AWM_HICP AWM_INFQ AWM_INFT AWM_INN AWM_INN_YEN AWM_ITD AWM_ITN AWM_ITR AWM_KSR AWM_LEN AWM_LFN AWM_LNN AWM_LNT AWM_LPROD AWM_LSL AWM_LSR AWM_LTN AWM_MTD AWM_MTN AWM_MTR AWM_NFA AWM_NFN AWM_NFN_YEN AWM_OGN AWM_OGN_YEN AWM_PCD AWM_PCN AWM_PCR AWM_PYN AWM_PYN_DIS AWM_PYN_DIS_YEN AWM_PYR AWM_S1 AWM_S3 AWM_SCD AWM_SCN AWM_SCR AWM_SSN AWM_SSN_YEN AWM_STN AWM_STRQ AWM_T931P AWM_TBN AWM_TBR AWM_TDN AWM_TDN_YEN AWM_TFT AWM_TIME AWM_TIN AWM_TIN_YEN AWM_TKN AWM_TKN_YEN AWM_TRN AWM_TRN_FIRMS AWM_TRN_FIRMS_YEN AWM_TRN_OTHER AWM_TRN_OTHER_YEN AWM_TRN_YEN AWM_ULC AWM_ULT AWM_UNN AWM_URT AWM_URX AWM_WIN AWM_WLN AWM_WLR AWM_WRN AWM_XTD AWM_XTN AWM_XTR AWM_YED AWM_YEN AWM_YEN_DIS AWM_YER AWM_YER_DIS AWM_YET AWM_YFD AWM_YFN AWM_YGA AWM_YIN AWM_YIN_DIS AWM_YWD AWM_YWDX AWM_YWR AWM_YWRX

'------------------------------------------------
' Exchange rate
'------------------------------------------------
' eurostat_ecu_euro_q.txt
' downloaded from EUROSTAT
smpl 1971:1 @last
read(skipcol=1) eurostat_ecu_euro_q.txt EUROSTAT_ECU_EURO
smpl @all

' store into the database
store EUROSTAT_ECU_EURO

'--------------------------------------------------------------------
' Construct weighted exchange rate: Synthetic EURUSD series
'
'	AWM weight: wi
'	BE: .036
'	DE: .283
'	ES: .111
'	FR: .201
'	IE: .015
'	IT: .195
'	LU: .003
'	NL: .060
'	AT: .030
'	PT: .024
'	FI: .017
'	GR: .025
'
' Euro fixed weight: fi
' http://www.ecb.int/bc/intro/html/index.en.html#fix
'
' 1 =
'
'   * BEF 40.3399 (Belgian francs)
'   * DEM 1.95583 (Deutsche Mark)
'   * ESP 166.386 (Spanish pesetas)
'   * FRF 6.55957 (French francs)
'   * IEP .787564 (Irish pounds)
'   * ITL 1936.27 (Italian lire)
'   * LUF 40.3399 (Luxembourg francs)
'   * NLG 2.20371 (Dutch guilders)
'   * ATS 13.7603 (Austrian schillings)
'   * PTE 200.482 (Portuguese escudos)
'   * FIM 5.94573 (Finnish markkas)
'   * GRD 340.750 (Greek drachmas)
'
' FX notation follows the convention that FX dealers use,
' i.e., USDDEM=1.9 implies 1 USD = 1.9 DEM.
'
' NCUUSD=ei, i.e., 1 NCUi = ei*USD
'
' Note that
'	1 EUR	= \prod_{i=1}^n (1 EUR)^wi
'			= \prod_{i=1}^n (fi*NCUi)^wi
'			= \prod_{i=1}^n (fi*ei*USD)^wi
' Hence,
'	EURUSD	= e
'			= \prod_{i=1}^n (fi*ei)^wi
'
' Taking logs to get
'	log(et)	= \sum_{i=1}^n wi*log(fi*eit)
'--------------------------------------------------------------------
' weight for each country
' AWM weight
!BE_AWM_W = .036
!DE_AWM_W = .283
!ES_AWM_W = .111
!FR_AWM_W = .201
!IE_AWM_W = .015
!IT_AWM_W = .195
!LU_AWM_W = .003
!NL_AWM_W = .060
!AT_AWM_W = .030
!PT_AWM_W = .024
!FI_AWM_W = .017
!GR_AWM_W = .025

'EURO weight
!BE_EURO_W = 40.3399
!DE_EURO_W = 1.95583
!ES_EURO_W = 166.386
!FR_EURO_W = 6.55957
!IE_EURO_W = .787564
!IT_EURO_W = 1936.27
!LU_EURO_W = 40.3399
!NL_EURO_W = 2.20371
!AT_EURO_W = 13.7603
!PT_EURO_W = 200.482
!FI_EURO_W = 5.94573
!GR_EURO_W = 340.750

' ifs_fx_euroland.xls
' downloaded from IFS (NCU per USD: USDNCU, 1/eit)
read(b10) ifs_fx_euroland.xls IFS_AT_USDNCU IFS_BE_USDNCU IFS_FR_USDNCU IFS_DE_USDNCU IFS_IT_USDNCU IFS_LU_USDNCU IFS_NL_USDNCU IFS_EU_USDNCU IFS_FI_USDNCU IFS_GR_USDNCU IFS_IE_USDNCU IFS_PT_USDNCU IFS_ES_USDNCU

' weighted FX (-1998)
genr EU_FX_AWM   = 0			' arithmetic average with AWM weight
genr EU_FX_SYNTH = 0			' geometric average with AWM weight
for	!i=0 to	11
	%cnn = @mid(%cn,1+3*!i,2)
	genr EU_FX_AWM   = EU_FX_AWM   + 1/IFS_{%cnn}_USDNCU*!{%cnn}_AWM_W
	genr EU_FX_SYNTH = EU_FX_SYNTH + !{%cnn}_AWM_W*log(!{%cnn}_EURO_W/IFS_{%cnn}_USDNCU)
next
genr EU_FX_SYNTH = exp(EU_FX_SYNTH)

' EURUSD (US dollar per EURO)
genr IFS_EURUSD  = 1/IFS_EU_USDNCU

' level adjustment EU_FX_AWM to EURUSD through EEN (EEN is USDEUR)
genr AWM_EEN_INV = 1/AWM_EEN

smpl 1998:1 1998:4
scalar SC_EEN98  = @mean(AWM_EEN_INV)
scalar SC_FX98   = @mean(EU_FX_AWM)
smpl 1999:1 1999:4
scalar SC_EEN99  = @mean(AWM_EEN_INV)
scalar SC_EURUSD99 = @mean(IFS_EURUSD)
smpl @all

genr EU_EURUSD_AWM = EU_FX_AWM/SC_FX98*SC_EEN98/SC_EEN99*SC_EURUSD99

'rename series
genr EU_EURUSD_SYNTH = EU_FX_SYNTH

' append EURUSD to FX (1999-)
smpl 1999:1 @last
genr EU_EURUSD_AWM    = IFS_EURUSD
genr EU_EURUSD_SYNTH  = IFS_EURUSD
smpl @all

' store into the database
store EU_EURUSD_SYNTH EU_EURUSD_AWM IFS_EURUSD



'------------------------------------------------
' comparision: Exchange rate and depreciations
'------------------------------------------------
fetch EUROSTAT_ECU_EURO
genr EUROSTAT_ECU_EURO_DEL = 100*log(EUROSTAT_ECU_EURO/EUROSTAT_ECU_EURO(-1))
genr EU_EURUSD_SYNTH_DEL   = 100*log(EU_EURUSD_SYNTH/EU_EURUSD_SYNTH(-1))

smpl 1971:1 @last

group GROUP_FX1 EU_EURUSD_SYNTH EUROSTAT_ECU_EURO AWM_EEN_INV
freeze(FIG_FX1) GROUP_FX1.line
FIG_FX1.setelem(1) legend("Synthetic EURO")
FIG_FX1.setelem(2) legend("ECU/EURO")
FIG_FX1.setelem(3) legend("AWM Effective Exchange Rate")
FIG_FX1.legend font(8) -inbox position(1.9,2.48)
FIG_FX1.addtext(l) US dollar per EURO

group GROUP_FX2 EU_EURUSD_SYNTH_DEL EUROSTAT_ECU_EURO_DEL
freeze(FIG_FX2) GROUP_FX2.line
FIG_FX2.setelem(1) legend("Synthetic EURO Depreciation")
FIG_FX2.setelem(2) legend("ECU/EURO Depreciation")
FIG_FX2.legend columns(1) font(8) -inbox position(1.9,2.6)
FIG_FX2.addtext(l) EURO Depreciation (Percent)

genr EURO_DEL_DIFF = EUROSTAT_ECU_EURO_DEL - EU_EURUSD_SYNTH_DEL
freeze(FIG_FX3) EURO_DEL_DIFF.line
FIG_FX3.legend -display
FIG_FX3.addtext(l) Difference in Depreciations

graph FIG_FX.merge FIG_FX1 FIG_FX2 FIG_FX3
FIG_FX.align(2,1,1)
show FIG_FX

smpl @all


'--------------------------------------------------------------------
' Series for model
'--------------------------------------------------------------------
' our definition of EURUSD
genr EU_EURUSD = EU_EURUSD_SYNTH

genr EU_CPIINFL = 400*log(AWM_HICP/AWM_HICP(-1))
genr EU_GDPDEFINFL = 400*log(AWM_YED/AWM_YED(-1))
genr EU_GDPGR = 100*(log(AWM_YER/EU_WPOP)-log(AWM_YER(-1)/EU_WPOP(-1)))
genr EU_FXDEP = 100*log(EU_EURUSD/EU_EURUSD(-1))

' store into the database
store EU_EURUSD EU_CPIINFL EU_GDPDEFINFL EU_GDPGR EU_FXDEP

' save workfile
save

