'=====================================================================
' Data preparation for
'
' "A Bayesian Look at New Open Economy Macroeconomics"
' by Thomas	Lubik and Frank	Schorfheide
'
' Coded	for	EViews 4.1
' by Sungbae An
' Last Updated:	05/02/2005
'=====================================================================

' set working directory	path
%path =	@runpath
' comment off line 13 if @runpath is not supported on your version of EViews
' elaborate in writing on your data directory, for example,
' %path = "d:\work\bnoe\data\"
cd "{%path}"

%smpl_f = "1983:1"
%smpl_l = "2002:4"

' create workfile
workfile us_euro q 1947:1 2005:4


'=====================================================================
' Euroland
'=====================================================================

' open EURO database
db {%path}\euro_awm\bnoe_euroland

' fetch EURO series
fetch EU_CPIINFL AWM_STN EU_GDPGR EU_FXDEP AWM_YER EU_WPOP EU_EURUSD AWM_YED

' rename EURO series
rename EU_CPIINFL PI_F
rename AWM_STN R_F
rename EU_GDPGR YGR_F
rename EU_FXDEP E_DEL


'=====================================================================
' US
'=====================================================================

' open US FRED2 database and fetch series
db {%path}\us_fred\bnoe_fred2_us
fetch US_CPIINFL FRED2_US_FEDFUNDS FRED2_US_GDPR US_WPOP FRED2_US_GDPDEF

' generate US output growth rate
genr US_GDPGR_W = 100*(log(FRED2_US_GDPR/US_WPOP)-log(FRED2_US_GDPR(-1)/US_WPOP(-1)))

' store in FRED2 database
db {%path}\us_fred\bnoe_fred2_us
store US_GDPGR_W US_WPOP

' rename US series
rename US_CPIINFL PI_US
rename FRED2_US_FEDFUNDS R_US
rename US_GDPGR_W YGR_US

'=====================================================================
' Comparison: US vs. EURO (Figure 1)
'=====================================================================

' In 2000 US dollars
' match base year: EU_GDPR from 1995 base into 2000 base
smpl 1995:1 1995:4
scalar AWM_YED_1995 = @mean(AWM_YED)		' supposed to be 1
smpl 2000:1 2000:4
scalar AWM_YED_2000 = @mean(AWM_YED)
smpl @all

genr EU_GDPR_2000 = AWM_YER*AWM_YED_1995/AWM_YED_2000

' GDP per capita, annulized, in thousands
genr US_GDPC_2000 = FRED2_US_GDPR*1000/US_WPOP
genr EU_GDPC_2000 = EU_GDPR_2000*4/EU_WPOP

smpl 2000:1 2000:4
scalar EURUSD_2000 = @mean(EU_EURUSD)
smpl @all

genr EU_GDPC_2000USD = EU_GDPC_2000*EURUSD_2000


' In 1995 US dollars
' match base year: US_GDPC from 2000 base into 1995 base
smpl 1995:1 1995:4
scalar FRED2_US_GDPDEF_1995 = @mean(FRED2_US_GDPDEF)
smpl 2000:1 2000:4
scalar FRED2_US_GDPDEF_2000 = @mean(FRED2_US_GDPDEF)
smpl @all

genr US_GDPR_1995 = FRED2_US_GDPR*FRED2_US_GDPDEF_2000/FRED2_US_GDPDEF_1995

' GDP per capita, annulized, in thousands
genr US_GDPC_1995 = US_GDPR_1995*1000/US_WPOP
genr EU_GDPC_1995 = AWM_YER*4/EU_WPOP

smpl 1995:1 1995:4
scalar EURUSD_1995 = @mean(EU_EURUSD)
smpl @all

genr EU_GDPC_1995USD = EU_GDPC_1995*EURUSD_1995


smpl {%smpl_f} {%smpl_l}
group GDPC_2000 US_GDPC_2000 EU_GDPC_2000USD
freeze(FIG_GDPC_2000)GDPC_2000.line
FIG_GDPC_2000.options -inbox linepat
FIG_GDPC_2000.setelem(1) legend("US")
FIG_GDPC_2000.setelem(2) legend("EURO") lpat(2)
FIG_GDPC_2000.addtext(t) "GDP per capita"
FIG_GDPC_2000.addtext(l) "2000 US Dollars (Thousands)"
FIG_GDPC_2000.legend columns(1) font(8) -inbox position(3.2,2.5)

group GDPC_1995 US_GDPC_1995 EU_GDPC_1995USD
freeze(FIG_GDPC_1995)GDPC_1995.line
FIG_GDPC_1995.options -inbox linepat
FIG_GDPC_1995.setelem(1) legend("US")
FIG_GDPC_1995.setelem(2) legend("EURO") lpat(2)
FIG_GDPC_1995.addtext(t) "GDP per capita"
FIG_GDPC_1995.addtext(l) "1995 US Dollars (Thousands)"
FIG_GDPC_1995.legend columns(1) font(8) -inbox position(3.2,2.5)
smpl @all

' log GDP per capita series, annulized, in 2000 USD
genr EU_GDPCL_2000  = log(EU_GDPC_2000USD)
genr US_GDPCL_2000  = log(US_GDPC_2000)
genr GDP_RATIO_2000 = US_GDPCL_2000 - EU_GDPCL_2000

' log GDP per capita series, annulized, in 1995 USD
genr EU_GDPCL_1995  = log(EU_GDPC_1995USD)
genr US_GDPCL_1995  = log(US_GDPC_1995)
genr GDP_RATIO_1995 = US_GDPCL_1995 - EU_GDPCL_1995

smpl {%smpl_f} {%smpl_l}
freeze(FIG_GDPRATIO_2000) GDP_RATIO_2000.line
FIG_GDPRATIO_2000.options -inbox
FIG_GDPRATIO_2000.legend -display
FIG_GDPRATIO_2000.addtext(t) "US/EURO GDP RATIO (in logs)"

freeze(FIG_GDPRATIO_1995) GDP_RATIO_1995.line
FIG_GDPRATIO_1995.options -inbox
FIG_GDPRATIO_1995.legend -display
FIG_GDPRATIO_1995.addtext(t) "US/EURO GDP RATIO (in logs)"
smpl @all


'=====================================================================
' Comparison: UIP Theory vs Evidence
'=====================================================================
' UIP: Theory
genr UIP_RESIDUAL = E_DEL - R_US(-1)/4 + R_F(-1)/4

smpl {%smpl_f} {%smpl_l}
' UIP: Regression
equation UIP_REG.ls E_DEL = C(1)+C(2)*(R_US(-1)-R_F(-1))/4
freeze(TABLE_UIP_REG) UIP_REG
UIP_REG.makeresid UIP_REG_RESID

group UIP_RESID UIP_RESIDUAL UIP_REG_RESID
freeze(FIG_UIP_RESID) UIP_RESID.line
FIG_UIP_RESID.options -inbox linepat
FIG_UIP_RESID.setelem(1) legend("Theory")
FIG_UIP_RESID.setelem(2) legend("Regression") lpat(2)
FIG_UIP_RESID.addtext(t) "UIP Residuals"
FIG_UIP_RESID.legend columns(1) font(8) -inbox position(2.8,2.5)
smpl @all

'=====================================================================
' Comparison: Exchange Rate Depreciation
'=====================================================================

' Real Exchange Rate Depreciation
genr S_DEL = E_DEL + PI_F/4 - PI_US/4

smpl {%smpl_f} {%smpl_l}
group E_S_DEL E_DEL S_DEL
freeze(FIG_E_S_DEL) E_S_DEL.line
FIG_E_S_DEL.options -inbox linepat
FIG_E_S_DEL.setelem(1) legend("Nominal")
FIG_E_S_DEL.setelem(2) legend("Real") lpat(2)
FIG_E_S_DEL.addtext(t) "Exchange Rate Depreciations"
FIG_E_S_DEL.legend columns(1) font(8) -inbox position(2.8,2.5)
smpl @all

graph FIGURE1_2000.merge FIG_GDPC_2000 FIG_GDPRATIO_2000 FIG_UIP_RESID FIG_E_S_DEL
FIGURE1_2000.align(2,1,1)
show FIGURE1_2000

graph FIGURE1_1995.merge FIG_GDPC_1995 FIG_GDPRATIO_1995 FIG_UIP_RESID FIG_E_S_DEL
FIGURE1_1995.align(2,1,1)
show FIGURE1_1995


smpl {%smpl_f} {%smpl_l}
'=====================================================================
' Comparison: US vs. EURO Area data
'=====================================================================
group GR_US R_US PI_US
freeze(FIG_US) GR_US.line
FIG_US.options -inbox linepat
FIG_US.setelem(1) legend("Interest Rate")
FIG_US.setelem(2) legend("Inflation") lpat(2)
FIG_US.addtext(t) "U.S."
FIG_US.legend columns(1) font(8) -inbox position(2.8,0.2)

group GR_EURO R_F PI_F
freeze(FIG_EURO) GR_EURO.line
FIG_EURO.options -inbox linepat
FIG_EURO.setelem(1) legend("Interest Rate")
FIG_EURO.setelem(2) legend("Inflation") lpat(2)
FIG_EURO.addtext(t) "Euro Area"
FIG_EURO.legend columns(1) font(8) -inbox position(2.8,0.2)

group GR_YGR YGR_US YGR_F
freeze(FIG_YGR) GR_YGR.line
FIG_YGR.options -inbox linepat
FIG_YGR.setelem(1) legend("US")
FIG_YGR.setelem(2) legend("Euro Area") lpat(2)
FIG_YGR.addtext(t) "Output Growth"
FIG_YGR.legend columns(1) font(8) -inbox position(2.8,0.2)

group GR_S_UIP UIP_RESIDUAL S_DEL
freeze(FIG_UIP) GR_S_UIP.line
FIG_UIP.options -inbox linepat
FIG_UIP.setelem(1) legend("UIP Residual")
FIG_UIP.setelem(2) legend("Real Exchange Depreciation") lpat(2)
FIG_UIP.addtext(t) "UIP and Real Exchange Rate"
FIG_UIP.legend columns(1) font(8) -inbox position(2.2,0.2)

graph FIGURE2.merge FIG_US FIG_EURO FIG_YGR FIG_UIP
FIGURE2.align(2,1,1.2)
show FIGURE2

smpl @all

'=====================================================================
' Output and save
'=====================================================================
' make output file
smpl {%smpl_f} {%smpl_l}

write(t=txt,na=.,d=c) us_euro.txt YGR_US PI_US R_US YGR_F PI_F R_F E_DEL
write(t=txt,na=.,d=c) figure1_1995.txt US_GDPC_1995 EU_GDPC_1995USD UIP_RESIDUAL UIP_REG_RESID E_DEL S_DEL
write(t=txt,na=.,d=c) figure1_2000.txt US_GDPC_2000 EU_GDPC_2000USD UIP_RESIDUAL UIP_REG_RESID E_DEL S_DEL

smpl @all

' save workfile
save