// EURO ECONOMY
// BENCHMARK MODEL: OUTPUT GROWTH RULE


var PI R Y A G Z C calC LAM Ygr_F INF_F R_F;

varexo EPS_Z EPS_A EPS_G EPS_R;

parameters tau h theta psi1 psi2 rhoR rhoG rhoZ rhoA
           rr_steady pi_steady gam_steady;

// replace
// bet = 1/(1+rr_steady/400);
// kap = (1-theta)/theta*(1-theta*bet)

model(linear);

        // Domestic firms price setting
//      PI = bet*PI(+1) + kap*( -LAM -A );
        PI = 1/(1+rr_steady/400)*PI(+1) + (1-theta)/theta*(1-theta/(1+rr_steady/400))*( -LAM -A );

        // Domestic habits
        (1-h)*calC = C - C(-1)*h + Z*h;

        // Marginal utility of consumption
//      -LAM  = calC*tau/(1-h*bet) - (h*bet)/(1-h*bet)*(tau*calC(+1)+Z(+1));
        -LAM  = calC*tau/(1-h/(1+rr_steady/400)) - (h/(1+rr_steady/400)/(1-h/(1+rr_steady/400)))*(tau*calC(+1)+Z(+1));

        // Market clearing
        Y  = C + G;

        // Domestic monetary policy rule
        R  = rhoR*R(-1) + (1-rhoR)*( psi1*PI + psi2*(Y + Z - Y(-1)) ) + EPS_R;

        // Euler equation
        -LAM  = -LAM(+1) - (R - PI(+1)) + Z(+1);

        // Exogenous shocks
        A  = rhoA*A(-1) + EPS_A;
        G  = rhoG*G(-1) + EPS_G;
        Z  = rhoZ*Z(-1) + EPS_Z;

        // Measurement equations
        INF_F  = pi_steady + 4*PI;
        R_F    = pi_steady + rr_steady + 4*gam_steady + 4*R;
        Ygr_F  = gam_steady + Y - Y(-1) + Z;

end;


estimated_params;

    //            STARTING VALUES  &   PRIORS
    theta,        0.5,1E-5,0.999,      BETA_PDF,0.75,0.15;
    tau,          2.7,1E-5,10,         GAMMA_PDF,2,0.5;
    h,            0.3,1E-5,0.999,      BETA_PDF,0.3,0.1;

    psi1,         1.5,0.95,10,         GAMMA_PDF,1.5,0.25;
    psi2,         0.5,1E-5,10,         GAMMA_PDF,0.5,0.25;

    rhoA,         0.86,1E-5,1,         BETA_PDF,0.8,0.1;
    rhoR,         0.81,1E-5,1,         BETA_PDF,0.5,0.2;
    rhoG,         0.96,1E-5,1,         BETA_PDF,0.8,0.1;

    rhoZ,         0.54,1E-5,1,         BETA_PDF,0.66,0.15;

    rr_steady,    0.5,0,10,            GAMMA_PDF,0.5,0.5;
    gam_steady,   0.5,-5,5,            NORMAL_PDF,0.4,0.2;
    pi_steady,    3.33,0,10,           GAMMA_PDF,7,2;

    stderr EPS_A, 2,1E-8,5,            INV_GAMMA_PDF,0.501326,0.262055;  //fs_dyn(0.4,4)
    stderr EPS_G, 0.6,1E-8,5,          INV_GAMMA_PDF,1.253314,0.655136;  //fs_dyn(1,4)
    stderr EPS_R, 0.15,1E-8,5,         INV_GAMMA_PDF,0.250663,0.131027;  //fs_dyn(0.2,4)

    stderr EPS_Z, 0.34,1E-8,5,         INV_GAMMA_PDF,0.626657,0.327568;  //fs_dyn(0.5,4)

end;

varobs Ygr_F INF_F R_F;

estimation(datafile=us_euro_data,mode_compute=4,mh_replic=20000,mh_jscale=0.25,presample=4);

// mode_compute=3
// load_mh_file
// nodiagnostic
// mode_file=MODEL1_mode
