/******************************************************************************
* FILTPLOT.G
* computes posterior mean and plots filtered shock processes
*
* upadted:  03/13/2005
******************************************************************************/
new;
closeall;
library pgraph;
cls;
outwidth 256;

changedir("c:\\projects\\active\\nber\\gauss");

format /mat /on /mb1 /ros 16,8;

_verbose = 1;

#include noe_spec.g;
#include pathspec.g;
#include noe_mod.src;


/** number of states  **/
para = noe_pmsv(msel);

{T1,TC,T0,TETA,RC}= dsgesolv(para,msel);

if msel[1]==0;           /** open economy **/
   nstate = cols(T1)+2+cols(T0)+2;
elseif msel[1]>0;        /** closed economy **/
   nstate = cols(T1)+1+cols(T0)+2;
endif;

/********************************************************
* Import data series
********************************************************/
#include loaddata.g;

nobs  = rows(YY);          /** number of observations **/


/********************************************************************
*  Load State Draws
********************************************************************/
mhrun  = "1";

lpath  = resupath $+ "\\mhrun" $+ mhrun;
lstate  = lpath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "smpm";

open fhstate = ^lstate for read;

drawrow = readr( fhstate, 1);
drawdim = cols(drawrow);
drawrow = seekr( fhstate, 1);


/********************************************************************
*  Part 1: Compute the mean of s(t)
********************************************************************/
state_m_mean  = zeros(1,drawdim);

eofloop = 0;
nblock  = 5;
ndraws  = 0;

if _verbose;
   "";
   "=============================================";
   "State Vector Draws                           ";
   "";
   "Model            " $lmodel;
   "Data set         " $dataselstr;
   "Prior            " $lprior;
   "Subsample        " $subTstr;
   "MHrun Index      " $mhrun;
   "=============================================";
   "";
   "Part 1: Mean ";
endif;

do until eofloop;

   state_m_block = readr( fhstate, nblock );
   state_m_mean  = state_m_mean + sumc(state_m_block)';
   ndraws = ndraws + rows(state_m_block);

   if _verbose;".";;pause(1e-20);endif;

   eofloop = eof(fhstate);

endo;

state_m_mean = state_m_mean'/ndraws;
statemean = reshape(state_m_mean,nstate,nobs)';

/********************************************************************
*  Part 2: Plot Smoothed States
********************************************************************/

/** state names **/
if msel[1]==0;          /** open economy **/

   state_names =
              "pi         " $|
              "pi_H       " $|
              "pi_F       " $|
              "pi*        " $|
              "pi_H*      " $|
              "pi_F*      " $|
              "lambda     " $|
              "lambda*    " $|
              "calC       " $|
              "calC*      " $|
              "c          " $|
              "c*         " $|
              "Y          " $|
              "Y*         " $|
              "q          " $|
              "q*         " $|
              "s          " $|
              "e_del      " $|
              "psi_F      " $|
              "psi_H*     " $|
              "R          " $|
              "R*         " $|
              "A          " $|
              "A*         " $|
              "g          " $|
              "g*         " $|
              "z          " $|
              "E[pi]      " $|
              "E[pi_H]    " $|
              "E[pi_F]    " $|
              "E[pi*]     " $|
              "E[pi_H*]   " $|
              "E[pi_F*]   " $|
              "E[calC]    " $|
              "E[calC*]   " $|
              "E[z]       " $|
              "E[s]       " $|
              "E[lambda]  " $|
              "Y(-1)      " $|
              "Y*(-1)     " $|
              "eps_R      " $|
              "eps_R*     " $|
              "eps_A      " $|
              "eps_A*     " $|
              "eps_g      " $|
              "eps_g*     " $|
              "eps_z      " $|
              "eps_e_del  " $|
              "piHdiff_H  " $|
              "mc_H       " ;

elseif msel[1]>0;       /** closed economy **/

   state_names =
              "pi         " $|
              "lambda     " $|
              "calC       " $|
              "c          " $|
              "Y          " $|
              "R          " $|
              "A          " $|
              "g          " $|
              "z          " $|
              "E[c]       " $|
              "E[pi]      " $|
              "E[calC]    " $|
              "E[z]       " $|
              "E[lambda]  " $|
              "Y(-1)      " $|
              "eps_R      " $|
              "eps_A      " $|
              "eps_g      " $|
              "eps_z      " $|
              "piHdiff_H  " $|
              "mc_H       " ;

endif;


graphset;
begwind;
margin(0,0,0.2,0.2);
window(4,ceil(nstate/4),0);
fonts("microb");

_ptitlht = 0.3;
_paxht = 0.3;
_pnumht = 0.25;
_pcolor =2 ;
_pltype = {6 1 2 2};
_protate = 0;
_plctrl = 0;
_plwidth = 5.5;
_psymsiz = 5;
_ptek = "filtplot.tkf";

xlabel("Year");

j = 1;
do until j > nstate;

   title(state_names[j]);
   xy(ti,statemean[.,j]);
   nextwind;

   j = j+1;

endo;

endwind;
