/******************************************************************************
* FILTPLOT.G
* computes posterior mean and plots filtered shock processes
*
* upadted:  03/13/2005
******************************************************************************/
new;
closeall;
library pgraph;
cls;
outwidth 256;

changedir("c:\\projects\\active\\nber\\gauss");

format /mat /on /mb1 /ros 16,8;

_verbose = 1;

#include noe_spec.g;
#include pathspec.g;
#include noe_mod.src;


/** number of states  **/
para = noe_pmsv(msel);

{T1,TC,T0,TETA,RC}= dsgesolv(para,msel);

if msel[1]==0;           /** open economy **/
   nstate = cols(T1)+2+cols(T0)+2;
elseif msel[1]>0;        /** closed economy **/
   nstate = cols(T1)+1+cols(T0)+2;
endif;


/********************************************************
* Import data series
********************************************************/
#include loaddata.g;

nobs  = rows(YY);          /** number of observations **/


/********************************************************************
*  Load State Draws
********************************************************************/

lpath   = workpath $+ "\\o1p2d1t0\\results\\mhrun1\\";
lstate  = lpath    $+ "o1p2d1t0smpm";

open fhstate = ^lstate for read;

drawrow = readr( fhstate, 1);
drawdim = cols(drawrow);
drawrow = seekr( fhstate, 1);


/********************************************************************
*  Part 1: Compute the mean of s(t)
********************************************************************/
state_m_mean  = zeros(1,drawdim);

eofloop = 0;
nblock  = 1;
ndraws  = 0;

do until eofloop;
   
   state_m_block = readr( fhstate, nblock );
   state_m_mean  = state_m_mean + sumc(state_m_block)';
   ndraws = ndraws + rows(state_m_block);

   if _verbose;".";;pause(1e-20);endif;

   eofloop = eof(fhstate);

endo;

state_m_mean = state_m_mean'/ndraws;
statemean1 = reshape(state_m_mean,nstate,nobs)';

closeall fhstate;

/********************************************************
* Import data series
********************************************************/
#include loaddata.g;

nobs  = rows(YY);          /** number of observations **/


/********************************************************************
*  load State Draws
********************************************************************/

lpath   = workpath $+ "\\o1p5d1t0\\results\\mhrun1\\";
lstate  = lpath    $+ "o1p5d1t0smpm";

open fhstate = ^lstate for read;

drawrow = readr( fhstate, 1);
drawdim = cols(drawrow);
drawrow = seekr( fhstate, 1);


/********************************************************************
*  Part 1: Compute the mean of s(t)
********************************************************************/
state_m_mean  = zeros(1,drawdim);

eofloop = 0;
nblock  = 5;
ndraws  = 0;

do until eofloop;

   state_m_block = readr( fhstate, nblock );
   state_m_mean  = state_m_mean + sumc(state_m_block)';
   ndraws = ndraws + rows(state_m_block);

   if _verbose;".";;pause(1e-20);endif;

   eofloop = eof(fhstate);

endo;

state_m_mean = state_m_mean'/ndraws;
statemean2 = reshape(state_m_mean,nstate,nobs)';

closeall fhstate;



/********************************************************************
*  Part 2: Plot Subset of Smoothed States
********************************************************************/

/** state names **/

v_pi         = 1;
v_pistar     = 4;
v_s          = 17;
v_psi_F      = 19;
v_psi_Hstar  = 20;

statemean_plot = zeros(nobs-1,4);

/* real depreciation rate */
statemean_plot[.,1] = statemean1[2:nobs,v_s] - statemean1[1:nobs-1,v_s];
statemean_plot[.,2] = statemean2[2:nobs,v_s] - statemean2[1:nobs-1,v_s];

/* lop gaps */
statemean_plot[.,3] = statemean1[2:nobs,v_psi_F];
statemean_plot[.,4] = statemean1[2:nobs,v_psi_Hstar];

state_names = "Depreciation Rate" $|
              "LOP-Gap US       " $|
              "LOP-Gap Euro Area" ;

graphset;
begwind;
margin(0,0,0.2,0.2);
window(3,1,0);
fonts("microb");

_ptitlht = 0.5;
_paxht = 0.4;
_pnumht = 0.35;
_pcolor = {1 4};
_protate = 0;
_plctrl = 0;
_plwidth = 5.5;
_psymsiz = 5;
_pltype = {6 4};
xlabel("Year");

title("Real Exchange Rate Depreciation");
_plegstr = "Model\000Data";
_plegctl = {2 4 0.5 2};
/* xy(ti[2:nobs],statemean_plot[.,1]~YY[2:nobs,7]); */
xy(ti[2:nobs],statemean_plot[.,1]~(YY[2:nobs,7]-YY[2:nobs,2]/4+YY[2:nobs,5]/4)); 
nextwind;

ytics(-12,12,4,1);
title("Law-of-One-Price Gaps");
_plegstr = "U.S.\000Euro Area";
_plegctl = {2 4 0.5 2};
xy(ti[2:nobs],statemean_plot[.,3:4]);
nextwind;

ytics(-4,4,2,1);
title("Real Exchange Rate Depreciation (Model)");
_plegstr = "Benchmark\000Flexible Import Prices";
_plegctl = {2 4 0.5 2};
xy(ti[2:nobs],statemean_plot[.,1:2]);

endwind;

