/******************************************************************************
* FILTPLOT.G
* computes posterior mean and plots filtered shock processes
*
* upadted:  03/13/2005
******************************************************************************/
new;
closeall;
library pgraph;
cls;
outwidth 256;

changedir("c:\\projects\\active\\nber\\gauss");

format /mat /on /mb1 /ros 16,8;

_verbose = 1;

#include noe_spec.g;
#include pathspec.g;
#include noe_mod.src;


/********************************************************
* Import data series
********************************************************/
#include loaddata.g;

nobs  = rows(YY);          /** number of observations **/


/********************************************************************
*  Load State Draws (I) 
********************************************************************/
mhrun  = "1";

lpath   = workpath $+ "\\o1p2d1t0\\results\\mhrun1\\";
lstate  = lpath    $+ "o1p2d1t0smpm";

nstate  = 48+2;

open fhstate = ^lstate for read;

drawrow = readr( fhstate, 1);
drawdim = cols(drawrow);
drawrow = seekr( fhstate, 1);

state_m_mean  = zeros(1,drawdim);

eofloop = 0;
nblock  = 5;
ndraws  = 0;

"Reading" $lstate;

do until eofloop;

   state_m_block = readr( fhstate, nblock );
   state_m_mean  = state_m_mean + sumc(state_m_block)';
   ndraws = ndraws + rows(state_m_block);

   if _verbose;".";;pause(1e-20);endif;

   eofloop = eof(fhstate);

endo;

closeall;

state_m_mean = state_m_mean'/ndraws;
statemean_o  = reshape(state_m_mean,nstate,nobs)';

/* select A A* G G* Z Y Y* */

v_y          = 13;
v_ystar      = 14;
v_A          = 23;
v_Astar      = 24;
v_g          = 25;
v_gstar      = 26;
v_z          = 27;

statemean_o_y     = statemean_o[.,v_y];
statemean_o_ystar = statemean_o[.,v_ystar];
statemean_o_a     = statemean_o[.,v_a];
statemean_o_astar = statemean_o[.,v_astar];
statemean_o_g     = statemean_o[.,v_g];
statemean_o_gstar = statemean_o[.,v_gstar];
statemean_o_z     = statemean_o[.,v_z];

/********************************************************************
*  Load State Draws (II) 
********************************************************************/
mhrun  = "1";

lpath   = workpath $+ "\\us1p1d1t0\\results\\mhrun1\\";
lstate  = lpath    $+ "us1p1d1t0smpm";

nstate  = 19+2;

open fhstate = ^lstate for read;

drawrow = readr( fhstate, 1);
drawdim = cols(drawrow);
drawrow = seekr( fhstate, 1);

state_m_mean  = zeros(1,drawdim);

eofloop = 0;
nblock  = 5;
ndraws  = 0;

"Reading" $lstate;

do until eofloop;

   state_m_block = readr( fhstate, nblock );
   state_m_mean  = state_m_mean + sumc(state_m_block)';
   ndraws = ndraws + rows(state_m_block);

   if _verbose;".";;pause(1e-20);endif;

   eofloop = eof(fhstate);

endo;

closeall;

state_m_mean = state_m_mean'/ndraws;
statemean_us = reshape(state_m_mean,nstate,nobs)';

/* select A G Z Y  */

v_y       = 5;
v_A       = 7;
v_g       = 8;
v_z       = 9;

statemean_us_y     = statemean_us[.,v_y];
statemean_us_a     = statemean_us[.,v_a];
statemean_us_g     = statemean_us[.,v_g];
statemean_us_z     = statemean_us[.,v_z];


/********************************************************************
*  Load State Draws (III) 
********************************************************************/
mhrun  = "1";

lpath   = workpath $+ "\\row1p1d1t0\\results\\mhrun1\\";
lstate  = lpath    $+ "row1p1d1t0smpm";
nstate  = 19+2;

open fhstate = ^lstate for read;

drawrow = readr( fhstate, 1);
drawdim = cols(drawrow);
drawrow = seekr( fhstate, 1);

state_m_mean  = zeros(1,drawdim);

eofloop = 0;
nblock  = 5;
ndraws  = 0;

"Reading" $lstate;

do until eofloop;

   state_m_block = readr( fhstate, nblock );
   state_m_mean  = state_m_mean + sumc(state_m_block)';
   ndraws = ndraws + rows(state_m_block);

   if _verbose;".";;pause(1e-20);endif;

   eofloop = eof(fhstate);

endo;

closeall;

state_m_mean  = state_m_mean'/ndraws;
statemean_row = reshape(state_m_mean,nstate,nobs)';

/* select A G Z Y  */

v_y       = 5;
v_A       = 7;
v_g       = 8;
v_z       = 9;

statemean_row_y   = statemean_row[.,v_y];
statemean_row_a   = statemean_row[.,v_a];
statemean_row_g   = statemean_row[.,v_g];
statemean_row_z   = statemean_row[.,v_z];

/********************************************************************
*  Generate plots
********************************************************************/

graphset;
begwind;
margin(0,0,0.2,0.2);
window(2,2,0);
fonts("microb");

_ptitlht = 0.3;
_paxht = 0.3;
_pnumht = 0.25;
_protate = 0;
_plctrl = 0;
_plwidth = 5.5;
_psymsiz = 5;

xlabel("Year");

_pcolor = {1 2 4};
_pltype = {6 1 2};
_plegstr = "NOEM\000Closed Ec";
_plegctl = {2 4 0.5 2};
title("Technology A");
xy(ti,statemean_o_a~statemean_us_a);
nextwind;

_pcolor = {1 4 2 };
_pltype = {6 2 1 };
title("Technology A*");
xy(ti,statemean_o_astar~statemean_row_a);
nextwind;


_pcolor = {1 2 4};
_pltype = {6 1 2};

title("Demand G");
xy(ti,statemean_o_g~statemean_us_g);
nextwind;

_pcolor = {1 4 2 };
_pltype = {6 2 1 };

title("Demand G*");
xy(ti,statemean_o_gstar~statemean_row_g);
endwind;


graphset;
begwind;
margin(0,0,0.2,0.2);
window(3,1,0);
fonts("microb");

_ptitlht = 0.3;
_paxht = 0.3;
_pnumht = 0.25;
_pcolor = {1 2 4};
_pltype = {6 1 2 2};
_protate = 0;
_plctrl = 0;
_plwidth = 5.5;
_psymsiz = 5;

xlabel("Year");

_pcolor = {1 2 4};
_pltype = {6 1 2};
_plegstr = "NOEM\000Closed Ec";
_plegctl = {2 4 0.5 2};
title("Output Deviations Y");
xy(ti,statemean_o_y~statemean_us_y);
nextwind;

_pcolor = {1 4 2 };
_pltype = {6 2 1 };
title("Output Deviations Y*");
xy(ti,statemean_o_ystar~statemean_row_y);
nextwind;

_pcolor = {1 2 4};
_pltype = {6 1 2};
_plegstr = "NOEM\000US Closed\000Euro Closed";
_plegctl = {2 4 0.5 2};
title("Technology Trend");
xy(ti,statemean_o_z~statemean_us_z~statemean_row_z);
endwind;
