/******************************************************************************
* FILTPLOT.G
* computes posterior mean and plots filtered shock processes
*
* upadted:  03/13/2005
******************************************************************************/
new;
closeall;
library pgraph;
cls;
outwidth 256;

changedir("c:\\projects\\active\\nber\\gauss");

format /mat /on /mb1 /ros 16,8;

_verbose = 1;

#include noe_spec.g;
#include pathspec.g;
#include noe_mod.src;


/********************************************************
* Import data series
********************************************************/
#include loaddata.g;

nobs  = rows(YY);          /** number of observations **/


/********************************************************************
*  Load State Draws (I) 
********************************************************************/
mhrun  = "1";

lpath   = workpath $+ "\\o1p2d1t0\\results\\mhrun1\\";
lstate  = lpath    $+ "o1p2d1t0smpm";
nstate = 48+2;

open fhstate = ^lstate for read;

drawrow = readr( fhstate, 1);
drawdim = cols(drawrow);
drawrow = seekr( fhstate, 1);

state_m_mean  = zeros(1,drawdim);

eofloop = 0;
nblock  = 5;
ndraws  = 0;

"Reading" $lstate;

do until eofloop;

   state_m_block = readr( fhstate, nblock );
   state_m_mean  = state_m_mean + sumc(state_m_block)';
   ndraws = ndraws + rows(state_m_block);

   if _verbose;".";;pause(1e-20);endif;

   eofloop = eof(fhstate);

endo;

closeall;

state_m_mean = state_m_mean'/ndraws;
statemean_o  = reshape(state_m_mean,nstate,nobs)';

/* select pi-bet*Epi, mc */

statemean_o_pi    = statemean_o[.,2];
statemean_o_Epi   = statemean_o[.,29];
statemean_o_piepi = statemean_o[.,cols(statemean_o)-1];
statemean_o_mc    = statemean_o[.,cols(statemean_o)];

/********************************************************************
*  Load State Draws (II) 
********************************************************************/
mhrun  = "1";

lpath   = workpath $+ "\\us1p1d1t0\\results\\mhrun1\\";
lstate  = lpath    $+ "us1p1d1t0smpm";
nstate  = 19+2;

open fhstate = ^lstate for read;

drawrow = readr( fhstate, 1);
drawdim = cols(drawrow);
drawrow = seekr( fhstate, 1);

state_m_mean  = zeros(1,drawdim);

eofloop = 0;
nblock  = 5;
ndraws  = 0;

"Reading" $lstate;

do until eofloop;

   state_m_block = readr( fhstate, nblock );
   state_m_mean  = state_m_mean + sumc(state_m_block)';
   ndraws = ndraws + rows(state_m_block);

   if _verbose;".";;pause(1e-20);endif;

   eofloop = eof(fhstate);

endo;

closeall;

state_m_mean = state_m_mean'/ndraws;
statemean_us = reshape(state_m_mean,nstate,nobs)';

/* select pi-bet*Epi mc  */

statemean_us_pi    = statemean_us[.,1];
statemean_us_Epi   = statemean_us[.,10];
statemean_us_piepi = statemean_us[.,cols(statemean_us)-1];
statemean_us_mc    = statemean_us[.,cols(statemean_us)];

/********************************************************************
*  Generate plots
********************************************************************/

graphset;
begwind;
margin(0,0,0.2,0.2);
window(3,2,0);
fonts("microb");

_ptitlht = 0.3;
_paxht = 0.3;
_pnumht = 0.25;
_protate = 0;
_plctrl = 0;
_plwidth = 5.5;
_psymsiz = 2;
_plctrl = -1;

xlabel("Marginal Costs");
ylabel("Inflation Diff");

xmin = -5;
xmax =  5;
ymin = -1;
ymax =  1;

theta_us = 0.65; 
theta_o  = 0.66;
theta_p  = 0.5;
kap_us = (1-theta_us)^2/theta_us;
kap_o  = (1-theta_o)^2/theta_o;
kap_p  = (1-theta_p)^2/theta_p;

xtics(xmin,xmax,0.5,1);
ytics(ymin,ymax,0.2,1);

_pcolor = {2 1 2 4};
_pltype = {0};
/* _plegstr = "NOEM\000Closed Ec"; */
/* _plegctl = {2 4 0.5 2};         */

_pline = ( 1 ~ 6 ~ ymin/kap_o ~ ymin  ~ ymax/kap_o ~ ymax ~ 3 ~ 1)|
         ( 1 ~ 1 ~ ymin/kap_p ~ ymin  ~ ymax/kap_p ~ ymax ~ 3 ~ 1);

title("(1,1) Two Country Model");
xy(statemean_o_mc,statemean_o_piepi);
nextwind;

_pline = ( 1 ~ 6 ~ xmin ~ xmin*kap_us ~ xmax ~ xmax*kap_us ~ 3 ~ 1)|
         ( 1 ~ 1 ~ ymin/kap_p ~ ymin  ~ ymax/kap_p ~ ymax ~ 3 ~ 1);

title("(1,2) Closed Economy Model");
xy(statemean_us_mc,statemean_us_piepi);
nextwind;

xtics(-2,2,0.5,1);
ytics(-2,2,0.5,1);

_pline = ( 1 ~ 1 ~ -2 ~ -2  ~ 2 ~ 2 ~ 3 ~ 1);

title("(2,1) Inflation");
xlabel("Two Country Model");
ylabel("Closed Economy");
xy(statemean_o_pi,statemean_us_pi);

nextwind;

title("(2,2) Expected Inflation");
xlabel("Two Country Model");
ylabel("Closed Economy");
xy(statemean_o_Epi,statemean_us_Epi);

nextwind;

xtics(-2,2,0.5,1);
ytics(-2,2,0.5,1);

_pline = ( 1 ~ 1 ~ -2 ~ -2  ~ 2 ~ 2 ~ 3 ~ 1);

title("(3,1) Inflation Diff");
xlabel("Two Country Model");
ylabel("Closed Economy");
xy(statemean_o_piepi,statemean_us_piepi);

nextwind;

xtics(-5,5,1,1);
ytics(-5,5,1,1);

_pline = ( 1 ~ 1 ~ -5 ~ -5  ~ 5 ~ 5 ~ 3 ~ 1);


title("(3,2) Marginal Costs");
xlabel("Two Country Model");
ylabel("Closed Economy");
xy(statemean_o_mc,statemean_us_mc);

endwind;