/******************************************************************************
* IRFPLOT.G
* plots the impulse response functions
*
* upadted:  03/11/2005
******************************************************************************/
new;
closeall;
library pgraph;
cls;
outwidth 256;

changedir("c:\\projects\\active\\nber\\gauss");

format /mat /on /mb1 /ros 16,8;


#include noe_spec.g;
#include pathspec.g;

/** length of irf **/
nirf = 12;
ti   = seqa(1,1,nirf);

/********************************************************************
* Read Posterior Simulation Summary Files
********************************************************************/
mhrun  = "1";

lpath  = resupath $+ "\\mhrun" $+ mhrun;
ldraw  = lpath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "irs";

open fhdraw = ^ldraw for read;

irf_m = readr(fhdraw,1);
irf_s = readr(fhdraw,1);
irf_hpd_l = readr(fhdraw,1);
irf_hpd_h = readr(fhdraw,1);

drawdim = cols(irf_m);

irf_m     = reshape(irf_m,drawdim/nirf,nirf)';
irf_hpd_l = reshape(irf_hpd_l,drawdim/nirf,nirf)';
irf_hpd_h = reshape(irf_hpd_h,drawdim/nirf,nirf)';


/********************************************************************
* Graph
********************************************************************/

/** name of observables **/
ystr     = "Output  " $|
           "Inflation" $|
           "Interest" $|
           "Output (*)  " $|
           "Inflation (*)" $|
           "Interest (*)" $|
           "Depreciation "
           ;

if msel[1]==0;

   /** number of observables **/
    ny = 7;

    /** name of shocks **/
   titlestr = "Eps(R)" $|
              "Eps(R*)" $|
              "Eps(A)" $|
              "Eps(A*) " $|
              "Eps(G)" $|
              "Eps(G*)" $|
              "Eps(Z)" $|
              "PPP Shock";

   /** number of shocks **/
   nep = 8;

   /** shock multiplier **/
   shmult = ones(nep,1) ;

elseif msel[1]>0;

   /** number of observables **/
    ny = 3;

   /** name of shocks **/
   titlestr = "Mon Policy"  $|
              "Stat Tech" $|
              "Gov" $|
              "Perm Tech";

   /** number of shocks **/
   nep = 4;

   /** shock multiplier **/
   shmult = ones(nep,1);

endif;



graphset;
begwind;
margin(0.2,0.2,0.2,0.2);
window(nep,ny+1,0);
fonts("microb");
_ptitlht = 0.6;
_paxht = 0.7;
_pnumht = 0.5;
_pcolor = {1 4 4};
_pltype = {6 2 2};
_protate = 0;
_plctrl = 0;
_plwidth = 5.5;
_psymsiz = 5;
_plegstr = "Mean\00090% HPD(U)\00090% HPD(L)";
/* _ptek = "irf.tkf"; */

sh_ind = 0;
do until sh_ind > nep-1;
/* iterate over shocks */

   y_ind = 0;
   do until y_ind > ny;
   /* iterate over endogenous variables */

      if (y_ind == 0) or (sh_ind == 0);
          nextwind;
      else;

         if (sh_ind == 1) and (y_ind > 1);

            _pmsgstr = ystr[y_ind];
            _pmsgctl = ( 1 ~ 6.5 ~ 0.9 ~ 0 ~ 2 ~ 0 ~ 0.7);

         elseif (sh_ind > 1) and (y_ind == 1);

            _pmsgstr = titlestr[sh_ind];
            _pmsgctl = ( -1 ~ 0.5 ~ 0.9 ~ 90 ~ 2 ~ 0 ~ 0.7);

         elseif (sh_ind == 1) and (y_ind == 1);

            _pmsgstr = ystr[y_ind] $+ "\000" $+ titlestr[sh_ind];
            _pmsgctl = ( 1 ~ 6.5 ~ 0.9 ~ 0 ~ 2 ~ 0 ~ 0.7) |
                       ( -1 ~ 0.5 ~ 0.9 ~ 90 ~ 2 ~ 0 ~ 0.7);
          
         else;

            _pmsgctl = 0;

         endif;

         xy(ti, shmult[sh_ind]*irf_m[.,ny*(sh_ind-1)+y_ind]
           ~ shmult[sh_ind]*irf_hpd_l[.,ny*(sh_ind-1)+y_ind]
           ~ shmult[sh_ind]*irf_hpd_h[.,ny*(sh_ind-1)+y_ind] );

         nextwind;


      endif;

      y_ind = y_ind + 1;
   endo;

   sh_ind = sh_ind + 1;
endo;

endwind;

/** export graph into .eps file **/
/*
_pqg_ps_Orientation = "portrait";
ret=tkf2eps(_ptek,"irf.eps");
*/
