/******************************************************************************
* IRFPMOM.G
* computes posterior mean and std and CI based on output of posterior simulator
* impulse response function
*
* upadted:  03/11/2005
******************************************************************************/
new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  _verbose = 1;           /** 1 for verbose **/

#include noe_spec.g;
#include pathspec.g;


/********************************************************************
* Load Parameter Draws from MH Output
********************************************************************/
mhrun   = "1";
nburn   = 501;    /* initial draws to be discarded */
hpdprob = 0.90;

lpath  = resupath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;

ldraw  = lpath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "ir";
odraws = opath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "irs";

open fhdraw = ^ldraw for read;

drawrow = readr(fhdraw,nburn);
drawdim = cols(drawrow);
drawrow = seekr(fhdraw,nburn);

/********************************************************************
* Part 1: Compute the mean of x(i) and x^2(i)
********************************************************************/
drawmean   = zeros(1,drawdim);
drawsqmean = zeros(1,drawdim);

eofloop = 0;
nblock  = 100;
ndraws  = 0;
ncols   = 12;

if _verbose;
   "";
   "=============================================";
   "Impulse Response Function                    ";
   "";
   "Model            " $lmodel;
   "Data set         " $dataselstr;
   "Prior            " $lprior;
   "Subsample        " $subTstr;
   "MHrun Index      " $mhrun;
   "Coverage         " hpdprob;
   "=============================================";
   "";
   "Part 1: Mean and Standard Deviation";
endif;

do until eofloop;

   drawblock  = readr( fhdraw, nblock );

   drawmean   = drawmean   + sumc(drawblock)';
   drawsqmean = drawsqmean + sumc(drawblock^2)';

   ndraws = ndraws + rows(drawblock);

   if _verbose;
      ".";;pause(1e-20);
   endif;

   eofloop = eof(fhdraw);

endo;

drawmean   = drawmean/ndraws;
drawsqmean = drawsqmean/ndraws;
drawstdd   = sqrt(drawsqmean - (drawmean)^2);


/********************************************************************
* Part 2: HPD Interval
********************************************************************/
drawrow = seekr(fhdraw,nburn);
drawci  = zeros(2,drawdim);

if _verbose;
   "";
   "Part 2: HPD Interval";
endif;

j = 1;
do until j > drawdim/ncols;

   /** Read only the j'th column **/
   drawrow   = seekr(fhdraw,nburn);
   drawblock = readr(fhdraw,1);

   drawcol = drawblock[1,(j-1)*ncols+1:j*ncols];
   eofloop = 0;
   ndraws  = 1;

   do until eofloop;

      drawblock = readr(fhdraw,nblock);
      drawcol   = drawcol | drawblock[.,(j-1)*ncols+1:j*ncols];
      ndraws    = ndraws + rows(drawblock);
      eofloop   = eof(fhdraw);

   endo;

   l = 1;
   do until l > ncols;
      drawci[.,(j-1)*ncols+l] = hpdint(drawcol[.,l],hpdprob);
      if _verbose;".";; pause(1e-20);endif;
      l = l+1;
   endo;

   if _verbose;"";endif;

   j = j+1;
endo;
clear drawcol;

create fhdraws = ^odraws with DRAWSUM, drawdim, 8;
wr = writer(fhdraws, real(drawmean|drawstdd|drawci) );
closeall fhdraws;

end;

/**************************************************************/
/*                         Procedures                         */
/**************************************************************/

proc(1) = hpdint(draws,percent);
local     ndraws, drawdim, hpdband, nwidth, i, drawcoli,
          bup, minwidth, newwidth, j;

drawdim = cols(draws);
ndraws  = rows(draws);
hpdband = zeros(2,drawdim);
nwidth  = int(percent*ndraws);

i = 1;
do until i > drawdim;
   drawcoli = draws[.,i];
   /* sort response for period i, element 1 is max
   */
   drawcoli = rev(sortc(drawcoli,1));
   bup   = 1;
   minwidth  = drawcoli[1] - drawcoli[nwidth];
   j = 2;
   do until j > (ndraws-nwidth+1);
      newwidth = drawcoli[j] - drawcoli[j+nwidth-1];
      if newwidth < minwidth;
         bup = j;
         minwidth = newwidth;
      endif;
      j = j+1;
   endo;
   hpdband[2,i] = drawcoli[bup];
   hpdband[1,i] = drawcoli[bup+nwidth-1];
   i = i+1;
endo;

retp(hpdband);
endp;
