/******************************************************************************
* NOE_AC.G
* converts the DSGE parameters into unconditional moments
* variance decomposition and autocovariances
*
* upadted:  03/11/2005
******************************************************************************/
new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  __output = 1;
  _fcmptol = 1E-10;
  _verbose = 1;           /** 1 for verbose **/

#include noe_spec.g;
#include pathspec.g;


/********************************************************************
* Load Parameter Draws from MH Output
********************************************************************/
mhrun  = "1";
nblock = 10000;    /* block size */
nuse   = 100;      /* use every nuse observation */

lpath  = parapath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;
chkdir = chk_dir(opath);

lpara  = lpath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "pa";

open fhpara = ^lpara for read;

/** check dimensions **/
para = noe_pmsv(msel);
{vd,ac} = dsgemom(para,msel);

nac = cols(ac);
nvd = rows(vd)*cols(vd);

/** Initialize Output files **/
oac  = opath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "ac";
ovd  = opath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "vd";

create fhac = ^oac with AC, nac, 8;
create fhvd = ^ovd with VD, nvd, 8;

/** Initialization **/
eofloop = 0;
loopct  = 1;

if _verbose;
   "";
   "Calculating moments...";
   "----------------------";
endif;

do until eofloop;

   if _verbose;
      "";
      "Block           " ftos(loopct,"%*.*lf",6,0);
   endif;

   /** Read blocks of size nblock **/
   parasim = readr(fhpara,nblock);
   nread   = rows(parasim);

   /** use every nuse-th draw **/
   indseq  = seqa(1,1,nread);
   indseq  = indseq % nuse;
   indseq  = indseq .NE 0;

   parasim = delif(parasim,indseq);
   nread   = rows(parasim);

if ismiss(parasim) == 0;

   acsim   = zeros(nread,nac);
   vdsim   = zeros(nread,nvd);

   j = 1;
   do until j > nread;
      para = parasim[j,.]';
      
      {vd,ac} = dsgemom(para,msel);

      /* variance Decompositions */
      vdsim[j,.] =  vec(vd')';

      /* autocovariances */
      acsim[j,.] = ac;

      if _verbose;
         if fmod(j,10)==0; ".";; pause(1e-20);endif;
      endif;
      j = j+1;
   endo;

    /** write Output **/
   wr = writer(fhac,acsim);
   wr = writer(fhvd,vdsim);

endif;

   if _verbose;
      "";
      "Draws Processed " ftos(rows(acsim),"%*.*lf",6,0);
        "";
   endif;

   loopct = loopct + 1;
   eofloop = eof(fhpara);

endo;

closeall fhpara, fhac, fhvd;

end;




/********************************************************************
* Procedure: DSGENORM
********************************************************************/
proc (2) = dsgemom(para,msel);

local i,j,sig_chol,
      ny,nstate,nz,nep,
      T1,TC,T0,TETA,RC,
      TT,QQ,RR,HH,DD,ZZ,VV,
      eq_pi,eq_r,eq_ygr,
      eq_pi_h,eq_r_h,eq_ygr_h,eq_pi_F,eq_r_F,eq_ygr_F,eq_e_del,
      v_pi,v_pistar,v_y,v_ystar,v_e_del,v_R,v_Rstar,
      v_z,v_ylag,v_ystarlag,
      e_R,e_Rstar,e_A,e_Astar,e_g,e_gstar,e_z,e_e_del,
      gam_steady,rr_steady,pi_steady,pi_steadystar,
      sigR,sigRstar,sigA,sigAstar,sigg,siggstar,sigz,sigedel,
      corr_RRstar,
      GAM0s,GAM1s,GAM0i,GAM1i,GAM0,GAM1,QQi,
      vd,ac,corr0,corr1,stddev;

/**********************************************************
**      Solve DSGE model
**********************************************************/
{T1,TC,T0,TETA,RC} = dsgesolv(para,msel);

/**********************************************************
**      System matrices for State-space
**********************************************************/
if msel[1]==0;       /** open economy **/

   /**********************************************************
   **      System matrices for State-space
   **********************************************************/

   /** observation indices **/
   eq_ygr_h = 1;
   eq_pi_h  = 2;
   eq_r_h   = 3;
   eq_ygr_F = 4;
   eq_pi_F  = 5;
   eq_r_F   = 6;
   eq_e_del = 7;

   ny = 7;

   /** variable indices **/
   v_pi         = 1;
   v_pistar     = 4;
   v_y          = 13;
   v_ystar      = 14;
   v_e_del      = 18;
   v_R          = 21;
   v_Rstar      = 22;
   v_z          = 27;

   /** shock indices **/
   e_R     = 1;
   e_Rstar = 2;
   e_A     = 3;
   e_Astar = 4;
   e_g     = 5;
   e_gstar = 6;
   e_z     = 7;
   e_e_del = 8;

   /** names to parameters **/
   rr_steady     = para[22];
   gam_steady    = para[23];
   pi_steady     = para[24];
   pi_steadystar = para[24]; /* impose common steady state inflation */
   sigA          = para[26];
   sigg          = para[27];
   sigR          = para[28];
   sigAstar      = para[29];
   siggstar      = para[30];
   sigRstar      = para[31];
   sigz          = para[32];
   sigedel       = para[33];
   corr_RRstar   = para[34];

   /*******************************************
   ** Transition equations with augmentation
   **
   ** z(t) = T1*z(t-1) + T0*e(t)
   ** x(t) = [z(t)',...]'
   **
   ** x(t) = TT*x(t-1) + RR*e(t)
   ** e(t) ~ iid N(0,QQ)
   *******************************************/
   nz  = cols(T1);
   nep = cols(T0);

   /** augmentation: v_ylag, v_ystarlag **/
   v_ylag = nz+1;
   v_ystarlag = nz+2;

   TT = zeros(nz+2,nz+2);
   TT[1:nz,1:nz]  = T1;
   TT[v_ylag,v_y] = 1;
   TT[v_ystarlag,v_ystar] = 1;

   QQ = zeros(nep,nep);
   QQ[e_R,e_R]         = sigR^2;
   QQ[e_Rstar,e_Rstar] = sigRstar^2;
   QQ[e_R,e_Rstar]     = sigR*sigRstar*corr_RRstar;
   QQ[e_A,e_A]         = sigA^2;
   QQ[e_Astar,e_Astar] = sigAstar^2;
   QQ[e_g,e_g]         = sigg^2;
   QQ[e_gstar,e_gstar] = siggstar^2;
   QQ[e_z,e_z]         = sigz^2;
   QQ[e_e_del,e_e_del] = sigedel^2;

   RR = T0|zeros(2,nep);

   /*******************************************
   ** Measurement equations
   **
   **  INF_US = pi_steady + 4*PI;
   **  R_US   = pi_steady + rr_steady + 4*gam_steady + 4*R;
   **  Ygr_US = gam_steady + Y - Y(-1) + Z;
   **  INF_F  = pi_steadystar + 4*PI_star;
   **  R_F    = pi_steadystar + rr_steady + 4*gam_steady + 4*R_star;
   **  Ygr_F  = gam_steady + Y_star - Y_star(-1) + Z;
   **  E_del  = e_del;
   **
   **  y(t) = DD + ZZ*x(t) + u(t)
   **  u(t) ~ N(0,HH)
   **
   **  cov(e(t),u(t)) = VV
   *******************************************/
   nstate = cols(TT);

   DD = zeros(ny,1);
   DD[eq_pi_h,1]  = pi_steady;
   DD[eq_r_h,1]   = pi_steady + rr_steady + 4*gam_steady;
   DD[eq_ygr_h,1] = gam_steady;
   DD[eq_pi_f,1]  = pi_steadystar;
   DD[eq_r_f,1]   = pi_steadystar + rr_steady + 4*gam_steady;
   DD[eq_ygr_f,1] = gam_steady;

   ZZ = zeros(ny,nstate);
   ZZ[eq_pi_h,v_pi]       =  4;

   ZZ[eq_r_h,v_R]         =  4;

   ZZ[eq_ygr_h,v_y]       =  1;
   ZZ[eq_ygr_h,v_ylag]    = -1;
   ZZ[eq_ygr_h,v_z]       =  1;

   ZZ[eq_pi_f,v_pistar]   =  4;

   ZZ[eq_r_f,v_Rstar]     =  4;

   ZZ[eq_ygr_f,v_ystar]   =  1;
   ZZ[eq_ygr_f,v_ystarlag]= -1;
   ZZ[eq_ygr_f,v_z]       =  1;

   ZZ[eq_e_del,v_e_del]   =  1;

   HH = 0;
   VV = zeros(nep,ny);



elseif msel[1]>0;    /** closed economy **/

   /** observation indices **/
   eq_ygr = 1;
   eq_pi  = 2;
   eq_r   = 3;

   ny = 3;

   /** variable indices **/
   v_pi      = 1;
   v_y       = 5;
   v_R       = 6;
   v_z       = 9;

   /** shock indices **/
   e_R  = 1;
   e_A  = 2;
   e_g  = 3;
   e_z  = 4;

   /** names to parameters **/
   rr_steady  = para[10];
   gam_steady = para[11];
   pi_steady  = para[12];
   sigA       = para[13];
   sigg       = para[14];
   sigR       = para[15];
   sigz       = para[16];

   /*******************************************
   ** Transition equations with augmentation
   **
   ** z(t) = T1*z(t-1) + T0*e(t)
   ** x(t) = [z(t)',...]'
   **
   ** x(t) = TT*x(t-1) + RR*e(t)
   ** e(t) ~ iid N(0,QQ)
   *******************************************/
   nz  = cols(T1);
   nep = cols(T0);

   /** augmentation: v_ylag **/
   v_ylag = nz+1;

   TT = zeros(nz+1,nz+1);
   TT[1:nz,1:nz]  = T1;
   TT[v_ylag,v_y] = 1;

   QQ = zeros(nep,nep);
   QQ[e_R,e_R] = sigR^2;
   QQ[e_A,e_A] = sigA^2;
   QQ[e_g,e_g] = sigg^2;
   QQ[e_z,e_z] = sigz^2;

   RR = T0|zeros(1,nep);

   /*******************************************
   ** Measurement equations
   **
   **  INF_US = pi_steady + 4*PI;
   **  R_US   = pi_steady + rr_steady + 4*gam_steady 4*R;
   **  Ygr_US = gam_steady + Y - Y(-1) + Z;
   **
   **  y(t) = DD + ZZ*x(t) + u(t)
   **  u(t) ~ N(0,HH)
   **
   **  cov(e(t),u(t)) = VV
   *******************************************/
   nstate = cols(TT);

   DD = zeros(ny,1);
   DD[eq_pi,1]  = pi_steady;
   DD[eq_r,1]   = pi_steady + rr_steady + 4*gam_steady;
   DD[eq_ygr,1] = gam_steady;

   ZZ = zeros(ny,nstate);
   ZZ[eq_pi,v_pi]    =  4;
   ZZ[eq_r,v_R]      =  4;
   ZZ[eq_ygr,v_y]    =  1;
   ZZ[eq_ygr,v_ylag] = -1;
   ZZ[eq_ygr,v_z]    =  1;

   HH = 0;
   VV = zeros(nep,ny);

endif;

/**********************************************************
**   variance decomposition and autocovariance
**********************************************************/

/** Choleski decomposition **/
/* sig_chol = chol(QQ); */
sig_chol = sqrt(QQ);

GAM0 = zeros(ny,ny);
GAM1 = zeros(ny,ny);
vd   = zeros(ny,cols(sig_chol));

i=1;
do until i>cols(sig_chol);

   QQi   = sig_chol[.,i]*sig_chol[.,i]';
   GAM0s = real(dlyap(TT,RR*QQi*RR'));
   GAM0i = ZZ*GAM0s*ZZ' + ZZ*RR*VV + (ZZ*RR*VV)' + HH;
   GAM1i = ZZ*(TT*GAM0s)*ZZ' + ZZ*(TT*RR*VV);

   GAM0 = GAM0 + GAM0i;
    GAM1 = GAM1 + GAM1i;

    vd[.,i] = diag(GAM0i);

    i = i+1;
endo;

/** variance decomposition **/
vd = vd./diag(GAM0);

/** autocovariance **/
corr0  = corrvc(GAM0);
stddev = sqrt(diag(GAM0));
corr1  = GAM1./(stddev*stddev');

/** ny + ny*(ny+1)/2 + ny^2 **/
ac = stddev'~vech(corr0)'~vec(corr1')';

retp(vd,ac);

endp;

#include noe_mod.src;
#include noe_lh.src;
