/******************************************************************************
* NOE_FILT.G
* computes smoothed estimates of the state vector
*
* upadted:  03/13/2005
******************************************************************************/
new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  __output = 1;
  _fcmptol = 1E-10;
  _verbose = 1;           /** 1 for verbose **/


#include noe_spec.g;
#include pathspec.g;

/** number of states  **/
para = noe_pmsv(msel);

{T1,TC,T0,TETA,RC}= dsgesolv(para,msel);

if msel[1]==0;           /** open economy **/
   nstate = cols(T1)+2+cols(T0);
elseif msel[1]>0;        /** closed economy **/
   nstate = cols(T1)+1+cols(T0);
endif;


/********************************************************
* Import data series
********************************************************/
#include loaddata.g;

nobs  = rows(YY);          /** number of observations **/

/********************************************************************
* Load Parameter Draws from MH Output
********************************************************************/
mhrun  = "1";
nblock = 50000;       /* block size */
nuse   = 50000;       /* use every nuse observation */

lpath  = parapath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;
chkdir = chk_dir(opath);

lpara  = lpath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "pa";

open fhpara = ^lpara for read;

/********************************************************************
* Initialize Output files
********************************************************************/
ostate_m = opath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "sm";
ostate_v = opath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "sv";
ostate_s = opath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "ss";

create fhostate_m = ^ostate_m with SSE, (nstate+2)*nobs, 8;
create fhostate_v = ^ostate_v with SSV, nstate*nobs, 8;
create fhostate_s = ^ostate_s with SSS, nstate*nobs, 8;

/********************************************************************
* Loop
********************************************************************/
/** Initialization **/
eofloop = 0;
loopct  = 1;

do until eofloop;

   if _verbose;
      "";
      "Block           " ftos(loopct,"%*.*lf",6,0);pause(1e-20);
   endif;

   /** Read blocks of size nblock **/
   parasim = readr(fhpara,nblock);
   nread = rows(parasim);

   /** use every nuse-th draw **/
   indseq = seqa(1,1,nread);
   indseq = indseq % nuse;
   indseq = indseq .NE 0;

   parasim = delif(parasim,indseq);
   nread = rows(parasim);

   statemean_sim = zeros(nread,(nstate+2)*nobs);
   statevar_sim  = zeros(nread,nstate*nobs);
   statesim_sim  = zeros(nread,nstate*nobs);

   j = 1;
   do until j > nread;

      para = parasim[j,.]';

      /* dimension: T*nstate */
      {statemean,statevar,statesim} = dsgefilt(para,YY,msel);
      
      /* augment the state vector */
      if msel[1] == 0;
         /* two country model */
         bet = 1/(1+para[22]/400);
         alp = para[7];

         statemean = statemean~
                     (statemean[.,2]-bet*statemean[.,29]) ~
                     (-statemean[.,7]-alp*statemean[.,15]-statemean[.,23]);

      else;
         /* one country model */
         bet = 1/(1+para[10]/400);
         statemean = statemean~
                     (statemean[.,1]-bet*statemean[.,10]) ~
                     (-statemean[.,2]-statemean[.,7]);        
      endif;

      statemean_sim[j,.] = vec(statemean)';
      statevar_sim[j,.]  = vec(statevar)';
      statesim_sim[j,.]  = vec(statesim)';

      if _verbose;
         if fmod(j,10)==0;".";; pause(1e-20);endif;
         if fmod(j,500)==0;"";pause(1e-20);endif;
      endif;

      j = j+1;

   endo;

   /** Write Output **/
   wr = writer(fhostate_m,statemean_sim);
   wr = writer(fhostate_v,statevar_sim);
   wr = writer(fhostate_s,statesim_sim);

   if _verbose;
      "";
      "Draws Processed " ftos(rows(statesim_sim),"%*.*lf",6,0);
      "";
   endif;

   loopct = loopct + 1;
   eofloop = eof(fhpara);

endo;

closeall fhpara, fhostate_m, fhostate_v, fhostate_s;

#include noe_filt.src;
#include noe_mod.src;
