/******************************************************************************
* NOE_FILTPM.G
* computes smoothed estimates of the state vector at posterior mean
*
* upadted:  03/13/2005
******************************************************************************/
new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  __output = 1;
  _fcmptol = 1E-10;
  _verbose = 1;           /** 1 for verbose **/


#include noe_spec.g;
#include pathspec.g;

/** number of states  **/
para = noe_pmsv(msel);

{T1,TC,T0,TETA,RC}= dsgesolv(para,msel);

if msel[1]==0;           /** open economy **/
   nstate = cols(T1)+2+cols(T0);
elseif msel[1]>0;        /** closed economy **/
   nstate = cols(T1)+1+cols(T0);
endif;


/********************************************************
* Import data series
********************************************************/
#include loaddata.g;

nobs  = rows(YY);          /** number of observations **/

/********************************************************************
* Load Posterior Mean
********************************************************************/
mhrun  = "1";

lpath  = parapath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;
chkdir = chk_dir(opath);

lpara  = lpath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "pas";

open fhpara = ^lpara for read;

/********************************************************************
* Initialize Output files
********************************************************************/
ostate_m = opath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "smpm";
ostate_v = opath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "svpm";
ostate_s = opath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "sspm";

create fhostate_m = ^ostate_m with SSE, (nstate+2)*nobs, 8;
create fhostate_v = ^ostate_v with SSV, nstate*nobs, 8;
create fhostate_s = ^ostate_s with SSS, nstate*nobs, 8;

parasim = readr(fhpara,1);
para    = parasim';

/* dimension: T*nstate */
{statemean,statevar,statesim} = dsgefilt(para,YY,msel);
      
/* augment the state vector */
if msel[1] == 0;
     /* two country model */
     bet = 1/(1+para[22]/400);
     alp = para[7];

     statemean = statemean~
                 (statemean[.,2]-bet*statemean[.,29]) ~
                 (-statemean[.,7]-alp*statemean[.,15]-statemean[.,23]);

else;
    /* one country model */
    bet = 1/(1+para[10]/400);
    statemean = statemean~
                (statemean[.,1]-bet*statemean[.,10]) ~
                (-statemean[.,2]-statemean[.,7]);        
endif;

statemean_sim = vec(statemean)';
statevar_sim  = vec(statevar)';
statesim_sim  = vec(statesim)';

     
/** Write Output **/
wr = writer(fhostate_m,statemean_sim);
wr = writer(fhostate_v,statevar_sim);
wr = writer(fhostate_s,statesim_sim);

closeall fhpara, fhostate_m, fhostate_v, fhostate_s;

#include noe_filt.src;
#include noe_mod.src;
