/******************************************************************************
* NOE_PM.G
* maximizes posterior density
*
* upadted:  03/08/2005
******************************************************************************/
new;

/** set seed **/
/** random number generator used in optimization procedure **/
rndseed 1234;

/********************************************************
* House cleaning and set defaults
********************************************************/
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
__output = 1;       /** 1 for verbose of CSMIN**/
__graph  = 1;       /** 1 for graph mode **/
_verbose = 2;       /** 0 for silence, 1 for compact, 2 for detailed**/
_fcmptol = 1E-10;

#include noe_spec.g;
#include pathspec.g;


/********************************************************
*  Import prior specification
********************************************************/
priorfile = lmodel $+ lprior $+ dataselstr $+ subTstr $+ "pr.txt";
load path = ^priopath prior[] = ^priorfile;
prior = reshape(prior,rows(prior)/5,5);

{prior,para_names} = noe_psel(prior,msel);

pshape   = prior[.,1];
pmean    = prior[.,2];
pstdd    = prior[.,3];
pmask    = prior[.,4];
pfix     = prior[.,5];
pmaskinv = 1-pmask;
pshape   = pshape.*pmaskinv;

/** starting value for maximization  **/
para  = noe_pmsv(msel);
npara = rows(para);
para  = para.*pmaskinv + pfix.*pmask;

/** alternatively, load some posterior mode estimates **/

lpara = "c:\\projects\\active\\nber\\gauss\\o1p1d1t0\\post\\o1p1d1t0pm";
open fhpara = ^lpara for read;
para = readr(fhpara,1)';
closeall fhpara;
para  = para.*pmaskinv + pfix.*pmask;



/** parameter specification: transformation **/
_trspec = noe_prtr(msel);
_trspec[.,1] = _trspec[.,1].*pmaskinv;

/** start log file **/
outstr = resupath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "pm.log";
output file = ^outstr reset;

/********************************************************
* Import data series
********************************************************/
#include loaddata.g;

nobs  = rows(YY);          /** number of observations **/

/********************************************************
* Calculate posterior density at starting values
* (verbose mode only)
********************************************************/
if _verbose;
    "Model              " $lmodel;
    "Prior              " $lprior;
    "Dataset            " $dataselstr;
    "Subsample          " $subTstr;    
    "===================================";
    "";
    "Prior Density at Starting Value:";; priodens(para,pmean,pstdd,pshape);
    lnpy = -objfcn(invtrans(para));
    "Posterior at Starting Value:    ";; lnpy;
    "";
    "Press Any Key to Continue.."; k = keyw;
    if not(__output);
    "";"";
    "Optimization in progress..";
    "--------------------------";
    endif;
endif;      /** _verbose **/


/********************************************************
* Maximize the posterior density
********************************************************/

/** initial values: x0 and H0 **/
cc = 0.0;
x0 = invtrans(para) + cc* ( rndn(npara,1) );
H0 = eye(npara)*1E-4;

/** set optimization routine environment **/
nit  = 1000;        /** maximum number of iteration **/
crit = 1E-7;        /** tolerance **/


/** Use personal optimization procedure **/
/** translated from Chris Sims' CSMIN package **/
{fh,xh,g,H,itct,fcount,_csretcode} = csminwel(x0,H0,crit,nit,&objfcn);

/** clear screen **/
if __output;
    cls;
else;
    "";
endif;


/********************************************************
* Save parameter estimates and return code
********************************************************/

/** max to model parameters **/
paraest = trans(xh);
paraest = real(paraest);
paraest = paraest.*pmaskinv + pfix.*pmask;


/** output file name **/
oparaest = postpath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "pm";
oretcode = postpath $+ "\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "pmret";

/** make output file **/
create fhparaest = ^oparaest with ^para_names, npara, 8;
wr = writer(fhparaest,paraest');
closeall fhparaest;

create fhretcode = ^oretcode with RETCODE, 1, 2;
wr = writer(fhretcode,_csretcode);
closeall fhretcode;



/********************************************************
* Estimation Output
********************************************************/
{lnpY,retcode,obserror,obsvar} = evalmod(paraest,YY,msel);

lnprio  = priodens( paraest, pmean, pstdd, pshape);

/* Compute gradient in terms of model parameters */
gradmod = g./ diag(gradp(&invtrans,paraest));

if _verbose;
    "";
    "Model              " $lmodel;
    "Prior              " $lprior;
    "Dataset            " $dataselstr;
    "Subsample          " $subTstr;    
    "===================================";
    "Posterior Mode     " (lnpy+lnprio);
    "Likelihood at Mode " lnpy;
    "Prior at Mode      " lnprio;
    "";
    "Parameter | Estimate | Start-V | Prior Mean | Prior Stdd | Gradient ";
    outmat = para_names'~paraest~trans(x0)~pmean~pstdd~gradmod;
    let mask[1,6] = 0 1 1 1 1 1;
    let fmt[6,3] = "-*.*s" 10 6
                   "*.*lf"  9 4
                   "*.*lf" 11 4
                   "*.*lf" 11 4
                   "*.*lf" 13 4
                   "*.*lf" 12 4;
    d = printfm(outmat,mask,fmt);
    "";
    "Return code:        ";; _csretcode;
    "";
endif;      /** _verbose **/

if lnpy == -1E6 ;
   end;
endif;



/********************************************************
* Compute Residuals
********************************************************/

/* moments */

    resid1 = obserror;
        resid1 = resid1[2:rows(resid1),.];

    resid1_m1 = meanc(resid1)';
    resid1_m2 = meanc( (resid1 - resid1_m1)^2 )';
    resid1_m3 = meanc( (resid1 - resid1_m1)^3 )';
    resid1_m4 = meanc( (resid1 - resid1_m1)^4 )';

    resid2 = obserror./sqrt(obsvar);
    resid2 = resid2[2:rows(resid2),.];
    resid2_m1 = meanc(resid1)';
    resid2_m2 = meanc( (resid2 - resid2_m1)^2 )';
    resid2_m3 = meanc( (resid2 - resid2_m1)^3 )';
    resid2_m4 = meanc( (resid2 - resid2_m1)^4 )';

    ti = ti[2:rows(ti)];

    nresid = rows(resid1);


/* autocorrelation */

    resid1_ar = zeros(1,3);
    resid2_ar = zeros(1,3);

    ind = 1;
    do until ind > 3;
       resid1_ar[1,ind] = inv(resid1[1:nresid-1,ind]'*resid1[1:nresid-1,ind])
                                *resid1[1:nresid-1,ind]'*resid1[2:nresid,ind];
       resid2_ar[1,ind] = inv(resid2[1:nresid-1,ind]'*resid2[1:nresid-1,ind])
                                *resid2[1:nresid-1,ind]'*resid2[2:nresid,ind];
       ind = ind+1;
    endo;


/** print on screen **/
if _verbose;
    "Raw Residuals";
    "-------------";
    "Mean:" resid1_m1;
    "Stdd:" sqrt(resid1_m2);
    "Skew:" resid1_m3./resid1_m2^(3/2);
    "Kurt:" resid1_m4./(3*resid1_m2^2);
    "Corr:" resid1_ar;
    "";
    "Standardized Residuals";
    "----------------------";
    "Mean:" resid2_m1;
    "Stdd:" sqrt(resid2_m2);
    "Skew:" resid2_m3./resid2_m2^(3/2);
    "Kurt:" resid2_m4./(3*resid2_m2^2);
    "Corr:" resid2_ar;
    "";
    
    titlestr = "DelY H" $|
               "Pi H  " $|
               "R H   " $|
               "DelY F" $|
               "Pi F  " $|
               "R F   " $|
               "DelE  "
               ;

    ystr     = "Raw Residual " $|
               "Stdd Residual"; 

    graphset;
    fonts("microb");
    _ptitlht = 0.4;
    _paxht = 0.4;
    _pnumht = 0.4;
          
    begwind;
    window(2,cols(YY),0);

    ser_ind = 1;
    do until ser_ind > cols(YY);

      ylabel(ystr[1]);
      title(titlestr[ser_ind]);
      xy(ti,resid1[.,ser_ind]);
 
      ser_ind = ser_ind+1;
      nextwind;

    endo;

    ser_ind = 1;
    do until ser_ind > cols(YY);

      ylabel(ystr[2]);
      title(titlestr[ser_ind]);
      xy(ti,resid2[.,ser_ind]);
 
      ser_ind = ser_ind+1;
      nextwind;

    endo;

endwind;
end;

endif;  /** _verbose **/


/** close log file **/
output file = ^outstr off;




/********************************************************
* PROCEDURE: OBJFCN
* defines the objective function to minimize:
* the negative of log posterior
*********************************************************/
proc (1) = objfcn(para);
local lnpY,lnprio,obserror,obsvar,modelpara,retcode;

/** likelihood **/
modelpara = trans(para);
modelpara = modelpara.*pmaskinv + pfix.*pmask;

{lnpY,retcode,obserror,obsvar} = evalmod(modelpara,YY,msel);

if ismiss(lnpY);
   lnpY = -1E8;
endif;

/** Evaluate the Prior distribution **/
lnprio = priodens(modelpara, pmean, pstdd, pshape);

/** minimize the negative of log posterior **/
retp(real(-lnpY-lnprio));
endp;

#include noe_mod.src;
#include noe_lh.src;
