/* filename:    paratab1.g
** description: generates a LaTeX Table  
*/

new;
closeall;
library user, pgraph;
cls;
outwidth 128;

#include noe_spec.g;
#include pathspec.g;

npara0 = 34;
npara1 = 16;


/******************************************************************
**         Load Parameter Draws from MH Output
*/

/* Specify input files - you have to edit the inputfile_str
** to read the desired estimates
** filename: lmodel + lprior + dataselstr + subTstr + pas
*/
/* raw data */
/*
inputfile_str = workpath $+ "\\o1p1d1t0\\para\\mhrun0\\o1p1d1t0pas"
             $| workpath $+ "\\o1p1d1t0\\para\\mhrun1\\o1p1d1t0pas"
             $| workpath $+ "\\us1p1d1t0\\para\\mhrun1\\us1p1d1t0pas"
             $| workpath $+ "\\row1p1d1t0\\para\\mhrun1\\row1p1d1t0pas";
*/
/* demeaned data */

inputfile_str = workpath $+ "\\o1p1d1t0\\para\\mhrun0\\o1p1d1t0pas"
             $| workpath $+ "\\o1p1d1t2\\para\\mhrun1\\o1p1d1t2pas"
             $| workpath $+ "\\us1p1d1t2\\para\\mhrun1\\us1p1d1t2pas"
             $| workpath $+ "\\row1p1d1t2\\para\\mhrun1\\row1p1d1t2pas";


/* Parameter transformation
*/
paratrind = zeros(npara0,2);

paratrind[1,1] = 1;
paratrind[5,1] = 2;
paratrind[6,1] = 3;
paratrind[9,1] = 4;
paratrind[10,1] = 5;
paratrind[15,1] = 6;
paratrind[16,1] = 7;
paratrind[17,1] = 8;
paratrind[21,1] = 9;
paratrind[22,1] = 10;
paratrind[23,1] = 11;
paratrind[24,1] = 12;
paratrind[26,1] = 13;
paratrind[27,1] = 14;
paratrind[28,1] = 15;
paratrind[32,1] = 16;

paratrind[4,2] = 1;
paratrind[5,2] = 2;
paratrind[6,2] = 3;
paratrind[12,2] = 4;
paratrind[13,2] = 5;
paratrind[18,2] = 6;
paratrind[19,2] = 7;
paratrind[20,2] = 8;
paratrind[21,2] = 9;
paratrind[22,2] = 10;
paratrind[23,2] = 11;
paratrind[24,2] = 12;
paratrind[29,2] = 13;
paratrind[30,2] = 14;
paratrind[31,2] = 15;
paratrind[32,2] = 16;

/* Specify row names for table
*/
row_name =  "$\\theta_H$"      
         $| "$\\theta_F$"      
         $| "$\\theta_H^*$"    
         $| "$\\theta_F^*$"    
         $| "$\\tau$"          
         $| "$h$"              
         $| "$\\alpha$"        
         $| "$\\eta$"          
         $| "$\\psi_1$"        
         $| "$\\psi_2$"        
         $| "$\\psi_3$"        
         $| "$\\psi_1^*$"      
         $| "$\\psi_2^*$"      
         $| "$\\psi_3^*$"      
         $| "$\\rho_A$"        
         $| "$\\rho_R$"        
         $| "$\\rho_G$"        
         $| "$\\rho_A^*$"      
         $| "$\\rho_R^*$"      
         $| "$\\rho_G^*$"      
         $| "$\\rho_Z$"        
         $| "$r^{(A)}$"        
         $| "$\\gamma$"        
         $| "$\\pi^{(A)}$"     
         $| "$\\pi^{*(A)}$"    
         $| "$\\sigma_A$"      
         $| "$\\sigma_G$"      
         $| "$\\sigma_R$"      
         $| "$\\sigma_{A^*}$"    
         $| "$\\sigma_{G^*}$"    
         $| "$\\sigma_{R^*}$"    
         $| "$\\sigma_Z$"      
         $| "$\\sigma_E$"      
         $| "$\\rho_{RR^{*}}$";
             
inputfile0_n = 2;
inputfile1_n = 2;

post_mean0 = zeros(npara0,inputfile0_n);
post_ci0   = zeros(npara0,inputfile0_n*2);

post_mean1 = zeros(npara1,inputfile1_n);
post_ci1   = zeros(npara1,inputfile1_n*2);

/* read the input files
*/
inputfile_ind = 1;

do until inputfile_ind > inputfile0_n;

   lparas = inputfile_str[inputfile_ind];
   open fhparas = ^lparas for read;
   
   post_mean0[.,inputfile_ind] = readr(fhparas,1)';
   drawrow = seekr(fhparas,npara0+3);
   post_ci0[.,2*(inputfile_ind-1)+1:2*inputfile_ind] = readr(fhparas,2)';

   inputfile_ind = inputfile_ind+1;
   
   closeall fhparas;
   
endo;

do until inputfile_ind > inputfile0_n+inputfile1_n;

   lparas = inputfile_str[inputfile_ind];
   open fhparas = ^lparas for read;
   
   post_mean1[.,inputfile_ind-inputfile0_n] = readr(fhparas,1)';
   drawrow = seekr(fhparas,npara1+3);
   post_ci1[.,2*(inputfile_ind-inputfile0_n-1)+1:2*(inputfile_ind-inputfile0_n)] = readr(fhparas,2)';

   inputfile_ind = inputfile_ind+1;
   
   closeall fhparas;
   
endo;


/* Create table
*/
para_ind = 1;
do until para_ind > npara0;

   tablerow = row_name[para_ind];

   inputfile_ind = 1;

   do until inputfile_ind > inputfile0_n;

      tablerow = tablerow $+ " & " $+ ftos(post_mean0[para_ind,inputfile_ind],"%*.*lf",5,2)
                 $+ " & [" $+ ftos(post_ci0[para_ind,2*(inputfile_ind-1)+1],"%*.*lf",5,2)
                 $+ ", "  $+ ftos(post_ci0[para_ind,2*(inputfile_ind)],"%*.*lf",5,2) $+ "]";

      inputfile_ind = inputfile_ind + 1;

   endo;

   inputfile_ind = 1;
   
   do until inputfile_ind > inputfile1_n;
      
      if paratrind[para_ind,inputfile_ind] == 0;
      
            tablerow = tablerow $+ " & " 
                 $+ " & " 
                 $+ "   ";
            
      else;
      
         paraindtr = paratrind[para_ind,inputfile_ind];
         tablerow = tablerow $+ " & " $+ ftos(post_mean1[paraindtr,inputfile_ind],"%*.*lf",5,2)
                 $+ " & [" $+ ftos(post_ci1[paraindtr,2*(inputfile_ind-1)+1],"%*.*lf",5,2)
                 $+ ", "  $+ ftos(post_ci1[paraindtr,2*(inputfile_ind)],"%*.*lf",5,2) $+ "]";
      endif;
                 
      inputfile_ind = inputfile_ind+1;
      
   endo;
   tablerow  = tablerow  $+ "\\\\";
   
   $tablerow;
   
   para_ind = para_ind+1;

endo;
