/* filename:    paratab0.g
** description: generates a LaTeX Table  
*/

new;
closeall;
library user, pgraph;
cls;
outwidth 128;

#include noe_spec.g;
#include pathspec.g;

para  = noe_pmsv(msel);
npara = rows(para);
{para,para_names} = noe_psel(para,msel);

/********************************************************
*  Import prior specification
********************************************************/
priorfile = lmodel $+ lprior $+ dataselstr $+ subTstr $+ "pr.txt";
load path = ^priopath prior[] = ^priorfile;
prior = reshape(prior,rows(prior)/5,5);

{prior,para_names} = noe_psel(prior,msel);

pshape   = prior[.,1];
pmean    = prior[.,2];
pstdd    = prior[.,3];


/******************************************************************
**         Load Parameter Draws from MH Output
*/

/* Specify input files
** filename: lmodel + lprior + dataselstr + subTstr + pas
*/
inputfile_str = "\\mhrun0\\" $+ lmodel $+ lprior $+ dataselstr $+ subTstr $+ "pas";

/* Specify row names for table
*/
row_name =  "$\\theta_H$      & $[0,1)$  & Beta  "
         $| "$\\theta_F$      & $[0,1)$  & Beta  "
         $| "$\\theta_H^*$    & $[0,1)$  & Beta  "
         $| "$\\theta_F^*$    & $[0,1)$  & Beta  "             
         $| "$\\tau$          & $\\RR^+$ & Gamma "
         $| "$h$              & $[0,1)$  & Beta  "
         $| "$\\alpha$        & $[0,1)$  & Beta  "
         $| "$\\eta$          & $\\RR^+$ & Gamma "                     
         $| "$\\psi_1$        & $\\RR^+$ & Gamma "
         $| "$\\psi_2$        & $\\RR^+$ & Gamma "
         $| "$\\psi_3$        & $\\RR^+$ & Gamma "
         $| "$\\psi_1^*$      & $\\RR^+$ & Gamma "
         $| "$\\psi_2^*$      & $\\RR^+$ & Gamma "
         $| "$\\psi_3^*$      & $\\RR^+$ & Gamma "         
         $| "$\\rho_A$        & $[0,1)$  & Beta  "
         $| "$\\rho_R$        & $[0,1)$  & Beta  "
         $| "$\\rho_G$        & $[0,1)$  & Beta  "
         $| "$\\rho_A^*$      & $[0,1)$  & Beta  "
         $| "$\\rho_R^*$      & $[0,1)$  & Beta  "
         $| "$\\rho_G^*$      & $[0,1)$  & Beta  "
         $| "$\\rho_Z$        & $[0,1)$  & Beta  "
         $| "$r^{(A)}$        & $\\RR^+$ & Gamma "
         $| "$\\gamma$        & $\\RR$   & Normal"
         $| "$\\pi^{(A)}$     & $\\RR^+$ & Gamma "
         $| "$\\pi^{*(A)}$    & $\\RR^+$ & Gamma "
         $| "$\\sigma_A$      & $\\RR^+$ & InvGamma "
         $| "$\\sigma_G$      & $\\RR^+$ & InvGamma "
         $| "$\\sigma_R$      & $\\RR^+$ & InvGamma "
         $| "$\\sigma_{A^*}$    & $\\RR^+$ & InvGamma "
         $| "$\\sigma_{G^*}$    & $\\RR^+$ & InvGamma "
         $| "$\\sigma_{R^*}$    & $\\RR^+$ & InvGamma "
         $| "$\\sigma_Z$      & $\\RR^+$ & InvGamma "
         $| "$\\sigma_E$      & $\\RR^+$ & InvGamma "
         $| "$\\rho_{RR^{*}}$ & $[-1,1]$ & Uniform  ";
             
inputfile_n = rows(inputfile_str);

post_mean = zeros(npara,inputfile_n);
post_stdd = zeros(npara,inputfile_n);
post_ci   = zeros(npara,inputfile_n*2);


/* read the input files
*/
inputfile_ind = 1;

do until inputfile_ind > inputfile_n;

   lparas = parapath $+ inputfile_str[inputfile_ind];
   open fhparas = ^lparas for read;
   
   post_mean[.,inputfile_ind] = readr(fhparas,1)';
   post_stdd[.,inputfile_ind] = readr(fhparas,1)';
   drawrow = seekr(fhparas,npara+3);
   post_ci[.,2*(inputfile_ind-1)+1:2*inputfile_ind] = readr(fhparas,2)';

   inputfile_ind = inputfile_ind+1;
   
   closeall fhparas;
   
endo;

/* Create table
*/
para_ind = 1;
do until para_ind > npara;

   tablerow = row_name[para_ind];

   inputfile_ind = 1;
   do until inputfile_ind > inputfile_n;
      
      tablerow = tablerow 
                 $+ " & " $+ ftos(pmean[para_ind],"%*.*lf",5,2)
                 $+ " & " $+ ftos(pstdd[para_ind,inputfile_ind],"%*.*lf",5,2);
                /*  $+ " & " $+ ftos(post_mean[para_ind,inputfile_ind],"%*.*lf",5,2)
                 $+ " & [" $+ ftos(post_ci[para_ind,2*(inputfile_ind-1)+1],"%*.*lf",5,2)
                 $+ ", "  $+ ftos(post_ci[para_ind,2*(inputfile_ind)],"%*.*lf",5,2) $+ "]"; */
      inputfile_ind = inputfile_ind+1;
      
   endo;
   tablerow  = tablerow  $+ "\\\\";
   
   $tablerow;
   
   para_ind = para_ind+1;

endo;
