/* filename:    paratab0-1.g
** description: generates a LaTeX Table  
*/

new;
closeall;
library user, pgraph;
cls;
outwidth 128;

#include noe_spec.g;
#include pathspec.g;

para  = noe_pmsv(msel);
npara = rows(para);
{para,para_names} = noe_psel(para,msel);

dist_name = "Beta" $|
            "Gamma" $|
            "Normal" $|
            "InvGamma" $|
            "Uniform" $|
            "None";

/* Specify row names for table
*/
row_name =  "$\\theta_H$      & $[0,1)$  & "
         $| "$\\theta_F$      & $[0,1)$  & "
         $| "$\\theta_H^*$    & $[0,1)$  & "
         $| "$\\theta_F^*$    & $[0,1)$  & "             
         $| "$\\tau$          & $\\RR^+$ & "
         $| "$h$              & $[0,1)$  & "
         $| "$\\alpha$        & $[0,1)$  & "
         $| "$\\eta$          & $\\RR^+$ & "                     
         $| "$\\psi_1$        & $\\RR^+$ & "
         $| "$\\psi_2$        & $\\RR^+$ & "
         $| "$\\psi_3$        & $\\RR^+$ & "
         $| "$\\psi_1^*$      & $\\RR^+$ & "
         $| "$\\psi_2^*$      & $\\RR^+$ & "
         $| "$\\psi_3^*$      & $\\RR^+$ & "         
         $| "$\\rho_A$        & $[0,1)$  & "
         $| "$\\rho_R$        & $[0,1)$  & "
         $| "$\\rho_G$        & $[0,1)$  & "
         $| "$\\rho_A^*$      & $[0,1)$  & "
         $| "$\\rho_R^*$      & $[0,1)$  & "
         $| "$\\rho_G^*$      & $[0,1)$  & "
         $| "$\\rho_Z$        & $[0,1)$  & "
         $| "$r^{(A)}$        & $\\RR^+$ & "
         $| "$\\gamma$        & $\\RR$   & "
         $| "$\\pi^{(A)}$     & $\\RR^+$ & "
         $| "$\\pi^{*(A)}$    & $\\RR^+$ & "
         $| "$\\sigma_A$      & $\\RR^+$ & "
         $| "$\\sigma_G$      & $\\RR^+$ & "
         $| "$\\sigma_R$      & $\\RR^+$ & "
         $| "$\\sigma_{A^*}$    & $\\RR^+$ & "
         $| "$\\sigma_{G^*}$    & $\\RR^+$ & "
         $| "$\\sigma_{R^*}$    & $\\RR^+$ & "
         $| "$\\sigma_Z$      & $\\RR^+$ &   "
         $| "$\\sigma_E$      & $\\RR^+$ &   "
         $| "$\\rho_{RR^{*}}$ & $[-1,1]$ &   ";

theta_H       = 1;
theta_F       = 2;
theta_Hstar   = 3;
theta_Fstar   = 4;
tau           = 5;
h             = 6;
alp           = 7;
eta           = 8;
psi1          = 9;
psi2          = 10;
psi3          = 11;
psi1star      = 12;
psi2star      = 13;
psi3star      = 14;
rhoA          = 15;
rhoR          = 16;
rhog          = 17;
rhoAstar      = 18;
rhoRstar      = 19;
rhogstar      = 20;
rhoz          = 21;
rr_steady     = 22;
gam_steady    = 23;
pi_steady     = 24;
pi_steadystar = 25;
sigA          = 26;
sigg          = 27;
sigR          = 28;
sigAstar      = 29;
siggstar      = 30;
sigRstar      = 31;
sigz          = 32;
sigedel       = 33;
corr_RRstar   = 34;


/********************************************************
*  Import prior specification
********************************************************/

/*********************/
/* Diffuse Prior (I) */

priorpath  = workpath $+ "\\o1p3d1t0\\prior\\";
priorfile = "o1p3d1t0pr.txt";
load path = ^priorpath prior[] = ^priorfile;
prior = reshape(prior,rows(prior)/5,5);
{prior,para_names} = noe_psel(prior,msel);

pshape   = prior[.,1];
pmean    = prior[.,2];
pstdd    = prior[.,3];

pshape_all = pshape[theta_H theta_F theta_Hstar theta_Fstar rhoA rhoR rhoG rhoAstar rhoRstar rhoGstar];
pmean_all  = pmean[theta_H theta_F theta_Hstar theta_Fstar rhoA rhoR rhoG rhoAstar rhoRstar rhoGstar];
pstdd_all  = pstdd[theta_H theta_F theta_Hstar theta_Fstar rhoA rhoR rhoG rhoAstar rhoRstar rhoGstar];
name_all   = row_name[theta_H theta_F theta_Hstar theta_Fstar rhoA rhoR rhoG rhoAstar rhoRstar rhoGstar];

/**********************/
/* Diffuse Prior (II) */

priorpath = workpath $+ "\\o1p4d1t0\\prior\\";
priorfile = "o1p4d1t0pr.txt";
load path = ^priorpath prior[] = ^priorfile;
prior = reshape(prior,rows(prior)/5,5);
{prior,para_names} = noe_psel(prior,msel);

pshape   = prior[.,1];
pmean    = prior[.,2];
pstdd    = prior[.,3];

pshape_all = pshape_all | pshape[ tau h alp eta ];
pmean_all  = pmean_all | pmean[tau h alp eta];
pstdd_all  = pstdd_all | pstdd[tau h alp eta];
name_all   = name_all $| row_name[tau h alp eta];
             

/* Create table
*/
para_ind = 1;
do until para_ind > rows(pshape_all);

      tablerow = name_all[para_ind] $+ dist_name[pshape_all[para_ind]] ;  
      
      tablerow = tablerow 
                 $+ " & " $+ ftos(pmean_all[para_ind],"%*.*lf",5,2)
                 $+ " & " $+ ftos(pstdd_all[para_ind],"%*.*lf",5,2);

      tablerow  = tablerow  $+ "\\\\";
   
      $tablerow;
   
      para_ind = para_ind+1;

endo;
